/* TI File $Revision: /main/1 $												*/
/* Checkin $Date: 15th Mar, 2013 $											*/
/****************************************************************************/
/*																			*/
/* FILE:	ADC.c															*/
/*																			*/
/* TITLE:	DSP28032/5 ADC module low level drivers.						*/
/*																			*/
/* This file contains low level drivers of ADC module dedicated for			*/
/* SAE LED project.															*/
/*																			*/
/*																			*/
/****************************************************************************/
/* $Release Date: $															*/
/****************************************************************************/

#include "DSP2803x_Device.h"
#include "DSP2803x_Examples.h"
#include "ADC.h"
#include "sys_config.h"

void adcConfigChannel(void)
{
    /* Perform fixed channel configuration for LED headlight application */
    EALLOW;

    AdcRegs.ADCSOC0CTL.bit.TRIGSEL = 0x0C;          /* select SOCA of ePWM3 as the trigger for SOC0 */
//    AdcRegs.ADCSAMPLEMODE.bit.SIMULEN0 = 0x01;      /* set SOC0 and SOC1 as simultaneous sampling mode */
    AdcRegs.ADCSOC0CTL.bit.CHSEL = 0x0C;            /* select ADCINA1 and ADCINB1 to be sampled simultaneously when SOC0/SOC1 happens*/
    AdcRegs.ADCSOC0CTL.bit.ACQPS = 0x06;            /* sample&hold time is set to 7 (6+1) clock cycles, in this project, 116.7ns */

    AdcRegs.ADCSOC1CTL.bit.TRIGSEL = 0x08;          /* select SOCA of ePWM3 as the trigger for SOC0 */
   //    AdcRegs.ADCSAMPLEMODE.bit.SIMULEN0 = 0x01;      /* set SOC0 and SOC1 as simultaneous sampling mode */
    AdcRegs.ADCSOC1CTL.bit.CHSEL = 0x0B;            /* select ADCINA1 and ADCINB1 to be sampled simultaneously when SOC0/SOC1 happens*/
    AdcRegs.ADCSOC1CTL.bit.ACQPS = 0x06;            /* sample&hold time is set to 7 (6+1) clock cycles, in this project, 116.7ns */


    AdcRegs.ADCSOC2CTL.bit.TRIGSEL = 0x0D;          /* select SOCA of ePWM5 as the trigger for SOC2 */
    AdcRegs.ADCSAMPLEMODE.bit.SIMULEN2 = 0x01;      /* set SOC2 and SOC3 as simultaneous sampling mode */
    AdcRegs.ADCSOC2CTL.bit.CHSEL = 0x02;            /* select ADCINA2 and ADCINB2 to be sampled simultaneously when SOC2/SOC3 happens*/
    AdcRegs.ADCSOC2CTL.bit.ACQPS = 0x06;            /* sample&hold time is set to 7 (6+1) clock cycles, in this project, 116.7ns */

//    AdcRegs.SOCPRICTL.bit.SOCPRIORITY = 0x04;       /* SOC0-3 are high priority SOCs, others are in round robin */
    AdcRegs.SOCPRICTL.bit.SOCPRIORITY = 0x0B;       /* SOC0-3 are high priority SOCs, others are in round robin */

    AdcRegs.ADCSOC4CTL.bit.TRIGSEL = 0x05;          /* select SOCA of ePWM1 as the trigger for SOC4 */
    AdcRegs.ADCSOC4CTL.bit.CHSEL = 0x03;            /* select ADCINA3 sampled when SOC4 happens*/
    AdcRegs.ADCSOC4CTL.bit.ACQPS = 0x06;            /* sample&hold time is set to 7 (6+1) clock cycles, in this project, 116.7ns */

    AdcRegs.ADCSOC5CTL.bit.TRIGSEL = 0x07;          /* select SOCA of ePWM2 as the trigger for SOC5 */
    AdcRegs.ADCSOC5CTL.bit.CHSEL = 0x04;            /* select ADCINA4 sampled when SOC5 happens*/
    AdcRegs.ADCSOC5CTL.bit.ACQPS = 0x06;            /* sample&hold time is set to 7 (6+1) clock cycles, in this project, 116.7ns */

    AdcRegs.ADCSOC6CTL.bit.TRIGSEL = 0x0B;          /* select SOCA of ePWM4 as the trigger for SOC6 */
    AdcRegs.ADCSOC6CTL.bit.CHSEL = 0x06;            /* select ADCINA6 sampled when SOC6 happens*/
    AdcRegs.ADCSOC6CTL.bit.ACQPS = 0x06;            /* sample&hold time is set to 7 (6+1) clock cycles, in this project, 116.7ns */

    AdcRegs.ADCSOC7CTL.bit.TRIGSEL = 0x06;          /* select SOCB of ePWM1 as the trigger for SOC7 */
    AdcRegs.ADCSOC7CTL.bit.CHSEL = 0x08;            /* select ADCINB0 sampled when SOC7 happens*/
    AdcRegs.ADCSOC7CTL.bit.ACQPS = 0x06;            /* sample&hold time is set to 7 (6+1) clock cycles, in this project, 116.7ns */

    AdcRegs.ADCSOC8CTL.bit.TRIGSEL = 0x08;          /* select SOCB of ePWM2 as the trigger for SOC8 */
    AdcRegs.ADCSOC8CTL.bit.CHSEL = 0x0B;            /* select ADCINB3 sampled when SOC8 happens*/
//    AdcRegs.ADCSOC8CTL.bit.CHSEL = 0x04;
    AdcRegs.ADCSOC8CTL.bit.ACQPS = 0x06;            /* sample&hold time is set to 7 (6+1) clock cycles, in this project, 116.7ns */

//    AdcRegs.ADCSAMPLEMODE.bit.SIMULEN8 = 0x01;      /* set SOC8 and SOC9 as simultaneous sampling mode */

    AdcRegs.ADCSOC9CTL.bit.TRIGSEL = 0x00;          /* select software trigger as the trigger for SOC9 */
    AdcRegs.ADCSOC9CTL.bit.CHSEL = 0x0E;            /* select ADCINB6 sampled when SOC9 happens*/
    AdcRegs.ADCSOC9CTL.bit.ACQPS = 0x3F;            /* sample&hold time is set to 7 (6+1) clock cycles, in this project, 116.7ns */

    AdcRegs.ADCSOC10CTL.bit.TRIGSEL = 0x00;          /* select software trigger as the trigger for SOC10 */
    AdcRegs.ADCSOC10CTL.bit.CHSEL = 0x0F;            /* select ADCINB7 sampled when SOC10 happens*/
    AdcRegs.ADCSOC10CTL.bit.ACQPS = 0x3F;            /* sample&hold time is set to 7 (6+1) clock cycles, in this project, 116.7ns */

    AdcRegs.ADCSOC11CTL.bit.TRIGSEL = 0x00;          /* select software trigger as the trigger for SOC10 */
	AdcRegs.ADCSOC11CTL.bit.CHSEL = 0x07;            /* select ADCINA7 sampled when SOC11 happens*/
	AdcRegs.ADCSOC11CTL.bit.ACQPS = 0x3F;            /* sample&hold time is set to 7 (6+1) clock cycles, in this project, 116.7ns */

    AdcRegs.ADCINTFLGCLR.all    = 0xFFFF;           /* clear all interrupt flags */
    AdcRegs.ADCINTOVFCLR.all    = 0xFFFF;           /* clear all interrupt overflow flags */
    AdcRegs.ADCSOCOVFCLR1.all   = 0xFFFF;           /* clear all SOC overflow flags */

    EDIS;
}

void adcEnableNotification(void)
{
    /* Enable ADCINT1 and ADCINT2   */

    EALLOW;

    /* ADCINT1 is triggered by EOC3 */
    AdcRegs.INTSEL1N2.bit.INT1CONT = 0x01;          /* continuous interrupt mode */
    AdcRegs.INTSEL1N2.bit.INT1SEL = 0x03;           /* ADCINT1 is triggered by EOC3 */
    AdcRegs.INTSEL1N2.bit.INT1E = 0x01;             /* enable interrupt of ADCINT1 */
    PieCtrlRegs.PIEIER1.bit.INTx1 = 0x01;           /* enable ADCINT1 in PIE */

    /* ADCINT2 is triggered by EOC9 */
    AdcRegs.INTSEL1N2.bit.INT2CONT = 0x01;          /* continuous interrupt mode */
    AdcRegs.INTSEL1N2.bit.INT2SEL = 0x08;           /* ADCINT2 is triggered by EOC8 */
    AdcRegs.INTSEL1N2.bit.INT2E = 0x01;             /* enable interrupt of ADCINT2 */
    PieCtrlRegs.PIEIER1.bit.INTx2 = 0x01;           /* enable ADCINT2 in PIE */

    /* ADCINT3 is triggered by EOC11 */
	AdcRegs.INTSEL3N4.bit.INT3CONT = 0x01;          /* continuous interrupt mode */
	AdcRegs.INTSEL3N4.bit.INT3SEL = 0x0B;           /* ADCINT2 is triggered by EOC11 */
	AdcRegs.INTSEL3N4.bit.INT3E = 0x01;             /* enable interrupt of ADCINT3 */
	//PieCtrlRegs.PIEIER1.bit.INTx3 = 0x01;           /* enable ADCINT3 in PIE */
	//No interrupt to be acknowledged by CPU

    EDIS;
}

void adcSoftwareSOCTrigger(Uint16 channel)
{
	/* trigger a SOC by setting the corresponding SOCFRC bit */

	EALLOW;

	AdcRegs.ADCSOCFRC1.all |= (0x0001 << channel);

	EDIS;
}

//SOC9, SOC10, SOC11 EOCs are bound to ADCINT9 in adcEnableNotification();
//Application specific routine...

Uint16 adcGetConversionResult(Uint16* pResult)
{
	/* read out the conversion result of the target SOC channel*/
	Uint16 success;
	success = 0;

	if(AdcRegs.ADCINTFLG.bit.ADCINT3 == On)	//SOC9, SOC10, SOC11 EOCs are bound to ADCINT9 in adcEnableNotification();
	{
		//Conversion finished.
		AdcRegs.ADCINTFLGCLR.bit.ADCINT3 = On;	//Clears the flag

		pResult[0] = AdcResult.ADCRESULT9;
		pResult[1] = AdcResult.ADCRESULT10;
		pResult[2] = AdcResult.ADCRESULT11;

		success = 1;
	}

	return success;
}
