// TI File $Revision: /main/3 $
// Checkin $Date: November 6, 2009   16:15:43 $
//###########################################################################
//
// FILE:    DSP2803x_ECan.c
//
// TITLE:   DSP2803x Enhanced CAN Initialization & Support Functions.
//
//###########################################################################
// $TI Release: 2803x C/C++ Header Files V1.21 $
// $Release Date: December 1, 2009 $
//###########################################################################

#include "DSP2803x_Device.h"     // DSP28 Headerfile Include File
#include "DSP2803x_Examples.h"   // DSP28 Examples Include File

//---------------------------------------------------------------------------
// InitECan:
//---------------------------------------------------------------------------
// This function initializes the eCAN module to a known state.
//
void InitECan(void)
{
   InitECana();
}

void InitECana(void)        // Initialize eCAN-A module
{

/* Create a shadow register structure for the CAN control registers. This is
 needed, since only 32-bit access is allowed to these registers. 16-bit access
 to these registers could potentially corrupt the register contents or return
 false data. */

struct ECAN_REGS ECanaShadow;

    EALLOW;     // EALLOW enables access to protected bits

/* Configure eCAN RX and TX pins for CAN operation using eCAN regs*/

    ECanaShadow.CANTIOC.all = ECanaRegs.CANTIOC.all;
    ECanaShadow.CANTIOC.bit.TXFUNC = 1;
    ECanaRegs.CANTIOC.all = ECanaShadow.CANTIOC.all;

    ECanaShadow.CANRIOC.all = ECanaRegs.CANRIOC.all;
    ECanaShadow.CANRIOC.bit.RXFUNC = 1;
    ECanaRegs.CANRIOC.all = ECanaShadow.CANRIOC.all;

/* Configure eCAN for HECC mode - (reqd to access mailboxes 16 thru 31) */
                                    // HECC mode also enables time-stamping feature

    ECanaShadow.CANMC.all = ECanaRegs.CANMC.all;
    ECanaShadow.CANMC.bit.SCB = 1U;     // enable full feature eCAN mode for 32 mailboxes and time-stamping function
    ECanaShadow.CANMC.bit.ABO = 1U;     // auto bus-on function is activated. (after detection of 128*11 recessive bits on bus.)

    /* Self test mode is selected for test purpose */

//    ECanaShadow.CANMC.bit.STM = 1U;     // enable self-test mode

    /* -- end of self test mode setting --*/

    ECanaRegs.CANMC.all = ECanaShadow.CANMC.all;

/* Initialize all bits of 'Message Control Register' to zero */
// Some bits of MSGCTRL register come up in an unknown state. For proper operation,
// all bits (including reserved bits) of MSGCTRL must be initialized to zero

    ECanaMboxes.MBOX[0].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[1].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[2].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[3].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[4].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[5].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[6].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[7].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[8].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[9].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[10].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[11].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[12].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[13].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[14].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[15].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[16].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[17].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[18].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[19].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[20].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[21].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[22].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[23].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[24].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[25].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[26].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[27].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[28].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[29].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[30].MSGCTRL.all = 0x00000000;
    ECanaMboxes.MBOX[31].MSGCTRL.all = 0x00000000;

// TAn, RMPn, GIFn bits are all zero upon reset and are cleared again
//  as a matter of precaution.

    ECanaRegs.CANTA.all = 0xFFFFFFFF;   /* Clear all TAn bits */

    ECanaRegs.CANRMP.all = 0xFFFFFFFF;  /* Clear all RMPn bits */

    ECanaRegs.CANGIF0.all = 0xFFFFFFFF; /* Clear all interrupt flag bits */
    ECanaRegs.CANGIF1.all = 0xFFFFFFFF;

/* Configure bit timing parameters for eCANA*/

    ECanaShadow.CANMC.all = ECanaRegs.CANMC.all;
    ECanaShadow.CANMC.bit.CCR = 1 ;            // Set CCR = 1
    ECanaRegs.CANMC.all = ECanaShadow.CANMC.all;

    // Wait until the CPU has been granted permission to change the configuration registers
    do
    {
      ECanaShadow.CANES.all = ECanaRegs.CANES.all;
    } while(ECanaShadow.CANES.bit.CCE != 1 );       // Wait for CCE bit to be set..

    ECanaShadow.CANBTC.all = 0;

    /* The following block is only for 60 MHz SYSCLKOUT. (30 MHz CAN module clock Bit rate = 1 Mbps
       See Note at end of file. */

    /* setting eCAN baudrate to 250Kbps */
    /* Baudrate = 1/(TSEG1 + TSEG2) */
    /* To achieve 75% sample point, TSEG1 = 3* TSEG2 */
    /* TSEG2 = 6* TQ, chosen after calculation based on 250Kbps */
    /* where, TQ = (BRPrescaler + 1)/(SysClockout/2) */
    /* Therefore, BRPrescaler is chosen to be 4.*/

    ECanaShadow.CANBTC.bit.BRPREG = 7;		//TQ = 8/30M = 267ns
    ECanaShadow.CANBTC.bit.TSEG2REG = 4U;	//4+1 = 5 TQ
    ECanaShadow.CANBTC.bit.TSEG1REG = 8U;	//8+1 = 9 TQ
    ECanaShadow.CANBTC.bit.SJWREG = 3U;		//SJW = 3+1 TQ

    ECanaShadow.CANBTC.bit.SAM = 1;
    ECanaRegs.CANBTC.all = ECanaShadow.CANBTC.all;

    ECanaShadow.CANMC.all = ECanaRegs.CANMC.all;
    ECanaShadow.CANMC.bit.CCR = 0 ;            // Set CCR = 0
    ECanaRegs.CANMC.all = ECanaShadow.CANMC.all;

    // Wait until the CPU no longer has permission to change the configuration registers
    do
    {
      ECanaShadow.CANES.all = ECanaRegs.CANES.all;
    } while(ECanaShadow.CANES.bit.CCE != 0 );       // Wait for CCE bit to be  cleared..

/* Disable all Mailboxes  */
    ECanaRegs.CANME.all = 0;        // Required before writing the MSGIDs

    EDIS;
}

//---------------------------------------------------------------------------
// Example: InitECanGpio:
//---------------------------------------------------------------------------
// This function initializes GPIO pins to function as eCAN pins
//
// Each GPIO pin can be configured as a GPIO pin or up to 3 different
// peripheral functional pins. By default all pins come up as GPIO
// inputs after reset.
//
// Caution:
// Only one GPIO pin should be enabled for CANTXA operation.
// Only one GPIO pin shoudl be enabled for CANRXA operation.
// Comment out other unwanted lines.

void InitECanGpio(void)
{
   InitECanaGpio();
}

void InitECanaGpio(void)
{
   EALLOW;

/* Enable internal pull-up for the selected CAN pins */
// Pull-ups can be enabled or disabled by the user.
// This will enable the pullups for the specified pins.
// Comment out other unwanted lines.

    GpioCtrlRegs.GPAPUD.bit.GPIO30 = 0;     // Enable pull-up for GPIO30 (CANRXA)
    GpioCtrlRegs.GPAPUD.bit.GPIO31 = 0;     // Enable pull-up for GPIO31 (CANTXA)

/* Set qualification for selected CAN pins to asynch only */
// Inputs are synchronized to SYSCLKOUT by default.
// This will select asynch (no qualification) for the selected pins.

    GpioCtrlRegs.GPAQSEL2.bit.GPIO30 = 3;   // Asynch qual for GPIO30 (CANRXA)

/* Configure eCAN-A pins using GPIO regs*/
// This specifies which of the possible GPIO pins will be eCAN functional pins.

    GpioCtrlRegs.GPAMUX2.bit.GPIO30 = 1;    // Configure GPIO30 for CANRXA operation
    GpioCtrlRegs.GPAMUX2.bit.GPIO31 = 1;    // Configure GPIO31 for CANTXA operation

    EDIS;
}

/* Note: Bit timing parameters must be chosen based on the network parameters such as
   the sampling point desired and the propagation delay of the network. The propagation
   delay is a function of length of the cable, delay introduced by the
   transceivers and opto/galvanic-isolators (if any).

   The parameters used in this file must be changed taking into account the above mentioned
   factors in order to arrive at the bit-timing parameters suitable for a network.
*/

//===========================================================================
// End of file.
//===========================================================================



