// TI File $Revision: /main/1 $
// Checkin $Date: December 18, 2012  $
//###########################################################################
//
// FILE:	System.c
//
// TITLE:	LED headlight project system initialization file.
//
//###########################################################################
// $TI Release: 2803x Internal Release 2 $
// $Release Date: November 11, 2008 $
//###########################################################################
#include "DSP2803x_Device.h"
#include "DSP2803x_Examples.h"
#include "sys_config.h"
#include "IQMathLib.h"
#include "SQMath.h"
#include "controller.h"
#include "ePWM.h"
#include "ADC.h"
#include "GPIO.h"
#include "eCAN.h"
#include "comm.h"
#include "system.h"
/* Put system startup and initialization code here */

void systemInit( void );    /* initialize all peripherals and system settings */
void clockTreeInit(void);   /* initialize system clock tree */

DIM_t dimming[7];	//6 channels + 1 dummy channel.

void systemInit(void)
{
    /* initiate system settings */
    InitSysCtrl();      /* 60MHz CPU clock, 60MHz system clock */

    InitPieCtrl();      /* disable PIE and clear all flags */
    InitPieVectTable(); /* initiate vector table */

#ifdef FLASH
// Copy time critical code and Flash setup code to RAM
// The  RamfuncsLoadStart, RamfuncsLoadEnd, and RamfuncsRunStart
// symbols are created by the linker. Refer to the linker files.
	MemCopy(&RamfuncsLoadStart, &RamfuncsLoadEnd, &RamfuncsRunStart);

// Call Flash Initialization to setup flash waitstates
// This function must reside in RAM
	InitFlash();	/* initialize flash setting, must be run from RAM */

#endif //(FLASH)

	//Device initialization
    InitGpio();			/* For debug LEDs */
    ePwmInit();         /* initialize ePWM modules */

    /* Initialize ADC */
    InitAdc();              /* Power ADC, this includes a BOOT ROM based ADC calibration function */
    InitAdcAio();           /* Set all AIO pins to analog input mode                    */

    /* Do not use now -- 2013-3-1 */
//    AdcOffsetSelfCal();     /* Calibrate zero error by calling pre-defined functions    */
    /* Do not use now -- 2013-3-1 */

    InitECan();
    InitECanGpio();

    eCANConfigRXMailbox(MailBox8, 0x501U, 0U, Enable_Data_Protection, Disable_Interrupt, Interrupt_Line_Dummy);
    eCANConfigRXMailbox(MailBox9, 0x502U, 0U, Enable_Data_Protection, Disable_Interrupt, Interrupt_Line_Dummy);
    eCANConfigRXMailbox(MailBox10, 0x503U, 0U, Enable_Data_Protection, Disable_Interrupt, Interrupt_Line_Dummy);

    eCANConfigTXMailbox(MailBox0, Disable_Interrupt, Interrupt_Line_Dummy);
    eCANConfigTXMailbox(MailBox1, Disable_Interrupt, Interrupt_Line_Dummy);
    eCANConfigTXMailbox(MailBox2, Disable_Interrupt, Interrupt_Line_Dummy);


    adcConfigChannel();

    adcEnableNotification();


}


/* Initializes the cpu timers */
void cpuTimerInit(void)
{
	// Timing sync for background loops
	// Timer period definitions found in PeripheralHeaderIncludes.h
//	CpuTimer0Regs.PRD.all =  mSec1;		// A tasks
	CpuTimer0Regs.PRD.all =  mSec0_5;
	CpuTimer1Regs.PRD.all =  mSec5;		// B tasks
	CpuTimer2Regs.PRD.all =  mSec50;	// C tasks
}

/* Initializes buck dimming function */
void buckDimmingInit(void)
{
	Uint16 i;
	for(i=1;i<7;i++)
	{
		dimming[i].phase = Off;
		dimming[i].duty = 0;
		dimming[i].count = 0;
	}
}

/* Buck dimming handler to be called every 1ms */
/* Dimming resolution of 10% @100Hz */

void buckDimmingHandler(void)
{
	Uint16 i;
	for(i=1;i<7;i++)
	{
		if(dimming[i].phase == Off)
		{
			if(dimming[i].count == 0U)
			{
				if(dimming[i].duty != 0U)
				{
					//turn PWM on
//					ePwmEnableOutput(i);
					EALLOW;
					EPwm1Regs.TZCLR.bit.OST = 1;
					EDIS;
					dimming[i].phase = On;
				}
				else
				{
					//duty is 0
					//keep PWM off
				}
			}
			else
			{
				//keep PWM off
			}
		}
		else if(dimming[i].phase == On)
		{
			if(dimming[i].count >= dimming[i].duty)
			{
				//turn PWM off
//				ePwmDisableOutput(i);
				EALLOW;
				EPwm1Regs.TZFRC.bit.OST = 1;
//				GpioCtrlRegs.GPAMUX1.bit.GPIO0 = 0;  // Configure GPIO0 as IO rather than EPWM1A
//				GpioDataRegs.GPASET.bit.GPIO0 = 1;   // Clear GPIO0 output to low
				EDIS;
				dimming[i].phase = Off;
			}
			else
			{
				//keep PWM on
			}
		}
		else
		{
			//error phase.
			buckDimmingInit();
		}

		dimming[i].count++;
		if(dimming[i].count >= 10U)
		{
			dimming[i].count = 0U;
		}

		//parameter error check
		if((dimming[i].count >= 10U)||(dimming[i].duty >= 10U))
		{
			//error parameter.
			buckDimmingInit();
		}
	}
}

