// TI File $Revision: /main/1 $
// Checkin $Date: Mar. 21st 2013  $
//###########################################################################
//
// FILE:	controller.c
//
// TITLE:	LED headlight project controller.
//
//###########################################################################
// $TI Release: 2803x Internal Release ? $
// $Release Date:  $
//###########################################################################

#include "DSP2803x_Device.h"
#include "DSP2803x_Examples.h"
#include "IQMathLib.h"
#include "SQMath.h"
#include "sys_config.h"
#include "controller.h"


#pragma CODE_SECTION(ControllerLead, "ramfuncs");
#pragma CODE_SECTION(ControllerLeadLag, "ramfuncs");
#pragma CODE_SECTION(ControllerPid, "ramfuncs");

/* Controller designs are coded here. */
/* for test:
 * a1 = -3.137
 * a2 = -3.365
 * b0 = 0.01422
 * b1 = 0.12852
 * b2 = 0
 * */
//#define Coefficient_a1	(0.7273)
//#define Coefficient_a2	(0)
//#define Coefficient_b0	(0.5466)
//#define Coefficient_b1	(-0.4961)
//#define Coefficient_b2	(0.0)

//#define Coefficient_a1	(1.0)
//#define Coefficient_a2	(0)
//#define Coefficient_b0	(0.001)
//#define Coefficient_b1	(0.0001)
//#define Coefficient_b2	(0.0)

#define Coefficient_a1	(0.9)
#define Coefficient_a2	(0.00)
#define Coefficient_b0	(0.004)
#define Coefficient_b1	(-0.002)
#define Coefficient_b2	(0.0)

extern float32 float_duty;


extern int16	*CNTL_2P2Z_Ref1, *CNTL_2P2Z_Out1, *CNTL_2P2Z_Fdbk1;
extern long		*CNTL_2P2Z_Coef1;

extern int16	*CNTL_2P2Z_Ref2, *CNTL_2P2Z_Ref3, *CNTL_2P2Z_Ref4, *CNTL_2P2Z_Ref5;
extern int16	*CNTL_2P2Z_Out2, *CNTL_2P2Z_Out3, *CNTL_2P2Z_Out4, *CNTL_2P2Z_Out5;
extern int16	*CNTL_2P2Z_Fdbk2, *CNTL_2P2Z_Fdbk3, *CNTL_2P2Z_Fdbk4, *CNTL_2P2Z_Fdbk5;
extern long		*CNTL_2P2Z_Coef2, *CNTL_2P2Z_Coef3, *CNTL_2P2Z_Coef4, *CNTL_2P2Z_Coef5;
extern int16	*CNTL_2P2Z_Ref6, *CNTL_2P2Z_Ref7, *CNTL_2P2Z_Ref8, *CNTL_2P2Z_Ref9;
extern int16	*CNTL_2P2Z_Out6, *CNTL_2P2Z_Out7, *CNTL_2P2Z_Out8, *CNTL_2P2Z_Out9;
extern int16	*CNTL_2P2Z_Fdbk6, *CNTL_2P2Z_Fdbk7, *CNTL_2P2Z_Fdbk8, *CNTL_2P2Z_Fdbk9;
extern long		*CNTL_2P2Z_Coef6, *CNTL_2P2Z_Coef7, *CNTL_2P2Z_Coef8, *CNTL_2P2Z_Coef9;


void coefficientInitialization(void)
{
	//    boostVoutAErrorCounter = 0;
	//    boostVoutADutyCounter = 0;
	//    boostVoutAReference = 993;	/* initialize reference value, as 8V */
	//    boostVoutAReference = 1396;		/* initialize reference value, as 12V */
	//    boostVoutAReference = 1861;		/* initialize reference value, as 16V */
//	    boostVoutAReference = 2234;		/* initialize reference value, as 18V */

	//    boostVoutBReference = 2606;		/* initialize reference value, as 21V */
	//    boostVoutBReference = 1861;
	//    boostVoutBReference = 2606;
//	    boostVoutBReference = 2234;		/* initialize reference value, as 18V */

	//    buckILED1Reference = 1200;		/* initialize reference value, as 0.5A */
	//    buckILED1Reference = 3376;		/* initialize reference value, as 1.0A */
	//    buckILED1Reference = 800;		/* initialize reference value, as ?? */

		//Initialize global control coefficient pointers.
		pBoostVoutA_PID = &boostVoutA_PID;
		pBoostVoutB_PID = &boostVoutB_PID;
		pBuckILED1_PID = &buckILED1_PID;
		pBuckILED2_PID = &buckILED2_PID;
		pBuckILED3_PID = &buckILED3_PID;
		pBuckILED4_PID = &buckILED4_PID;
		pBuckILED5_PID = &buckILED5_PID;
		pBuckILED6_PID = &buckILED6_PID;

	    /***************************************************/
	    /*           BOOST A PID initialization         ****/
	    /***************************************************/

	/* initialize Lead controller data values */
//	    boostVoutA.duty_0 = 0.3;
//	    boostVoutA.duty_1 = 0.3;
//	    boostVoutA.duty_2 = 0.3;
//	    boostVoutA.error_0 = 0;
//	    boostVoutA.error_1 = 0;
//	    boostVoutA.error_2 = 0;
//	    boostVoutA.duty_max = 0.60;
//	    boostVoutA.duty_min = 0;

	/* initialize PID terminal values */
	    pBoostVoutA_PID->term.Fbk = 0;
	    pBoostVoutA_PID->term.Out = 0;
	    pBoostVoutA_PID->term.Ref = 0;
	    pBoostVoutA_PID->term.c1 = _IQ(0.0);
	    pBoostVoutA_PID->term.c2 = _IQ(0.0);

	/* initialize PID parameter values */
	    pBoostVoutA_PID->param.Kd = _IQ(0.05);
	    pBoostVoutA_PID->param.Ki = _IQ(0.8);
	    pBoostVoutA_PID->param.Km = _IQ(1.0);
	    pBoostVoutA_PID->param.Kp = _IQ(0.4);
	    pBoostVoutA_PID->param.Kr = _IQ(1.0);
	    pBoostVoutA_PID->param.Umax = _IQ(0.68);		/* 8V in --> 25V out */
	    pBoostVoutA_PID->param.Umin = _IQ(0.0);

	/* initialize PID data values */
	    pBoostVoutA_PID->data.up = _IQ(0.0);
	    pBoostVoutA_PID->data.ui = _IQ(0.0);
	    pBoostVoutA_PID->data.ud = _IQ(0.0);
	    pBoostVoutA_PID->data.d1 = _IQ(0.0);
	    pBoostVoutA_PID->data.d2 = _IQ(0.0);
	    pBoostVoutA_PID->data.i1 = _IQ(0.0);
	    pBoostVoutA_PID->data.v1 = _IQ(0.0);
	    pBoostVoutA_PID->data.w1 = _IQ(0.0);

	    /***************************************************/
	    /*           BOOST B PID initialization         ****/
	    /***************************************************/
	/* initialize Lead controller data values */
//		boostVoutB.duty_0 = 0.3;
//		boostVoutB.duty_1 = 0.3;
//		boostVoutB.duty_2 = 0.3;
//		boostVoutB.error_0 = 0;
//		boostVoutB.error_1 = 0;
//		boostVoutB.error_2 = 0;
//		boostVoutB.duty_max = 0.60;
//		boostVoutB.duty_min = 0;

	/* initialize PID terminal values */
		pBoostVoutB_PID->term.Fbk = 0;
		pBoostVoutB_PID->term.Out = _IQ(0.0);
		pBoostVoutB_PID->term.Ref = 0;
		pBoostVoutB_PID->term.c1 = _IQ(0.0);
		pBoostVoutB_PID->term.c2 = _IQ(0.0);

	/* initialize PID parameter values */
		pBoostVoutB_PID->param.Kd = _IQ(0.05);
		pBoostVoutB_PID->param.Ki = _IQ(0.8);
		pBoostVoutB_PID->param.Km = _IQ(1.0);
		pBoostVoutB_PID->param.Kp = _IQ(0.8);
		pBoostVoutB_PID->param.Kr = _IQ(1.0);
		pBoostVoutB_PID->param.Umax = _IQ(0.68);		/* 8V in --> 25V out */
		pBoostVoutB_PID->param.Umin = _IQ(0.0);

	/* initialize PID data values */
		pBoostVoutB_PID->data.up = _IQ(0.0);
		pBoostVoutB_PID->data.ui = _IQ(0.0);
		pBoostVoutB_PID->data.ud = _IQ(0.0);
		pBoostVoutB_PID->data.d1 = _IQ(0.0);
		pBoostVoutB_PID->data.d2 = _IQ(0.0);
		pBoostVoutB_PID->data.i1 = _IQ(0.0);
		pBoostVoutB_PID->data.v1 = _IQ(0.0);
		pBoostVoutB_PID->data.w1 = _IQ(0.0);


	    /***************************************************/
	    /*           BUCK 1 PID initialization          ****/
	    /***************************************************/

	    /* initialize PID terminal values */
	    pBuckILED1_PID->term.Fbk = 0;
	    pBuckILED1_PID->term.Out = 0;
	    pBuckILED1_PID->term.Ref = 0;
	    pBuckILED1_PID->term.c1 = _IQ(0.2);
	    pBuckILED1_PID->term.c2 = _IQ(0.5);

	    /* initialize PID parameter values */
	    pBuckILED1_PID->param.Kd = _IQ(0.001);
	    pBuckILED1_PID->param.Ki = _IQ(0.8);
	    pBuckILED1_PID->param.Km = _IQ(0.5);
	    pBuckILED1_PID->param.Kp = _IQ(0.4);
	    pBuckILED1_PID->param.Kr = _IQ(1.0);
	    pBuckILED1_PID->param.Umax = _IQ(0.90);
	    pBuckILED1_PID->param.Umin = _IQ(0.0);

	    /* initialize PID data values */
	    pBuckILED1_PID->data.up = _IQ(0.0);
	    pBuckILED1_PID->data.ui = _IQ(0.0);
	    pBuckILED1_PID->data.ud = _IQ(0.0);
	    pBuckILED1_PID->data.d1 = _IQ(0.0);
	    pBuckILED1_PID->data.d2 = _IQ(0.0);
	    pBuckILED1_PID->data.i1 = _IQ(0.0);
	    pBuckILED1_PID->data.v1 = _IQ(0.0);
	    pBuckILED1_PID->data.w1 = _IQ(0.0);

	    /***************************************************/
	    /*           BUCK 2 PID initialization          ****/
	    /***************************************************/

	    /* initialize PID terminal values */
	    pBuckILED2_PID->term.Fbk = 0;
	    pBuckILED2_PID->term.Out = 0;
	    pBuckILED2_PID->term.Ref = 0;
	    pBuckILED2_PID->term.c1 = _IQ(0.2);
	    pBuckILED2_PID->term.c2 = _IQ(0.5);

	    /* initialize PID parameter values */
	    pBuckILED2_PID->param.Kd = _IQ(0.001);
	    pBuckILED2_PID->param.Ki = _IQ(0.8);
	    pBuckILED2_PID->param.Km = _IQ(0.5);
	    pBuckILED2_PID->param.Kp = _IQ(0.4);
	    pBuckILED2_PID->param.Kr = _IQ(1.0);
	    pBuckILED2_PID->param.Umax = _IQ(0.90);
	    pBuckILED2_PID->param.Umin = _IQ(0.0);

	    /* initialize PID data values */
	    pBuckILED2_PID->data.up = _IQ(0.0);
	    pBuckILED2_PID->data.ui = _IQ(0.0);
	    pBuckILED2_PID->data.ud = _IQ(0.0);
	    pBuckILED2_PID->data.d1 = _IQ(0.0);
	    pBuckILED2_PID->data.d2 = _IQ(0.0);
	    pBuckILED2_PID->data.i1 = _IQ(0.0);
	    pBuckILED2_PID->data.v1 = _IQ(0.0);
	    pBuckILED2_PID->data.w1 = _IQ(0.0);

	    /***************************************************/
	    /*           BUCK 3 PID initialization          ****/
	    /***************************************************/

	    /* initialize PID terminal values */
	    pBuckILED3_PID->term.Fbk = 0;
	    pBuckILED3_PID->term.Out = 0;
	    pBuckILED3_PID->term.Ref = 0;
	    pBuckILED3_PID->term.c1 = _IQ(0.2);
	    pBuckILED3_PID->term.c2 = _IQ(0.5);

	    /* initialize PID parameter values */
	    pBuckILED3_PID->param.Kd = _IQ(0.001);
	    pBuckILED3_PID->param.Ki = _IQ(0.8);
	    pBuckILED3_PID->param.Km = _IQ(0.5);
	    pBuckILED3_PID->param.Kp = _IQ(0.4);
	    pBuckILED3_PID->param.Kr = _IQ(1.0);
	    pBuckILED3_PID->param.Umax = _IQ(0.90);
	    pBuckILED3_PID->param.Umin = _IQ(0.0);

	    /* initialize PID data values */
	    pBuckILED3_PID->data.up = _IQ(0.0);
	    pBuckILED3_PID->data.ui = _IQ(0.0);
	    pBuckILED3_PID->data.ud = _IQ(0.0);
	    pBuckILED3_PID->data.d1 = _IQ(0.0);
	    pBuckILED3_PID->data.d2 = _IQ(0.0);
	    pBuckILED3_PID->data.i1 = _IQ(0.0);
	    pBuckILED3_PID->data.v1 = _IQ(0.0);
	    pBuckILED3_PID->data.w1 = _IQ(0.0);

	    /***************************************************/
	    /*           BUCK 4 PID initialization          ****/
	    /***************************************************/

	    /* initialize PID terminal values */
	    pBuckILED4_PID->term.Fbk = 0;
	    pBuckILED4_PID->term.Out = 0;
	    pBuckILED4_PID->term.Ref = 0;
	    pBuckILED4_PID->term.c1 = _IQ(0.2);
	    pBuckILED4_PID->term.c2 = _IQ(0.5);

	    /* initialize PID parameter values */
	    pBuckILED4_PID->param.Kd = _IQ(0.001);
	    pBuckILED4_PID->param.Ki = _IQ(0.8);
	    pBuckILED4_PID->param.Km = _IQ(0.5);
	    pBuckILED4_PID->param.Kp = _IQ(0.4);
	    pBuckILED4_PID->param.Kr = _IQ(1.0);
	    pBuckILED4_PID->param.Umax = _IQ(0.90);
	    pBuckILED4_PID->param.Umin = _IQ(0.0);

	    /* initialize PID data values */
	    pBuckILED4_PID->data.up = _IQ(0.0);
	    pBuckILED4_PID->data.ui = _IQ(0.0);
	    pBuckILED4_PID->data.ud = _IQ(0.0);
	    pBuckILED4_PID->data.d1 = _IQ(0.0);
	    pBuckILED4_PID->data.d2 = _IQ(0.0);
	    pBuckILED4_PID->data.i1 = _IQ(0.0);
	    pBuckILED4_PID->data.v1 = _IQ(0.0);
	    pBuckILED4_PID->data.w1 = _IQ(0.0);

	    /***************************************************/
	    /*           BUCK 5 PID initialization          ****/
	    /***************************************************/

	    /* initialize PID terminal values */
	    pBuckILED5_PID->term.Fbk = 0;
	    pBuckILED5_PID->term.Out = 0;
	    pBuckILED5_PID->term.Ref = 0;
	    pBuckILED5_PID->term.c1 = _IQ(0.2);
	    pBuckILED5_PID->term.c2 = _IQ(0.5);

	    /* initialize PID parameter values */
	    pBuckILED5_PID->param.Kd = _IQ(0.001);
	    pBuckILED5_PID->param.Ki = _IQ(0.8);
	    pBuckILED5_PID->param.Km = _IQ(0.5);
	    pBuckILED5_PID->param.Kp = _IQ(0.4);
	    pBuckILED5_PID->param.Kr = _IQ(1.0);
	    pBuckILED5_PID->param.Umax = _IQ(0.90);
	    pBuckILED5_PID->param.Umin = _IQ(0.0);

	    /* initialize PID data values */
	    pBuckILED5_PID->data.up = _IQ(0.0);
	    pBuckILED5_PID->data.ui = _IQ(0.0);
	    pBuckILED5_PID->data.ud = _IQ(0.0);
	    pBuckILED5_PID->data.d1 = _IQ(0.0);
	    pBuckILED5_PID->data.d2 = _IQ(0.0);
	    pBuckILED5_PID->data.i1 = _IQ(0.0);
	    pBuckILED5_PID->data.v1 = _IQ(0.0);
	    pBuckILED5_PID->data.w1 = _IQ(0.0);

	    /***************************************************/
	    /*           BUCK 6 PID initialization          ****/
	    /***************************************************/

	    /* initialize PID terminal values */
	    pBuckILED6_PID->term.Fbk = 0;
	    pBuckILED6_PID->term.Out = 0;
	    pBuckILED6_PID->term.Ref = 0;
	    pBuckILED6_PID->term.c1 = _IQ(0.2);
	    pBuckILED6_PID->term.c2 = _IQ(0.5);

	    /* initialize PID parameter values */
	    pBuckILED6_PID->param.Kd = _IQ(0.001);
	    pBuckILED6_PID->param.Ki = _IQ(0.8);
	    pBuckILED6_PID->param.Km = _IQ(0.5);
	    pBuckILED6_PID->param.Kp = _IQ(0.4);
	    pBuckILED6_PID->param.Kr = _IQ(1.0);
	    pBuckILED6_PID->param.Umax = _IQ(0.90);
	    pBuckILED6_PID->param.Umin = _IQ(0.0);

	    /* initialize PID data values */
	    pBuckILED6_PID->data.up = _IQ(0.0);
	    pBuckILED6_PID->data.ui = _IQ(0.0);
	    pBuckILED6_PID->data.ud = _IQ(0.0);
	    pBuckILED6_PID->data.d1 = _IQ(0.0);
	    pBuckILED6_PID->data.d2 = _IQ(0.0);
	    pBuckILED6_PID->data.i1 = _IQ(0.0);
	    pBuckILED6_PID->data.v1 = _IQ(0.0);
	    pBuckILED6_PID->data.w1 = _IQ(0.0);

}

void ControllerLead(controllerDataBuffer_t* outputChannel)
{
	float32 A1, A2, B0, B1, B2;

	A1 = (float32)Coefficient_a1 * outputChannel->duty_1;
	A2 = (float32)Coefficient_a2 * outputChannel->duty_2;
	B0 = (float32)Coefficient_b0 * outputChannel->error_0;
	B1 = (float32)Coefficient_b1 * outputChannel->error_1;
	B2 = (float32)Coefficient_b2 * outputChannel->error_2;

	outputChannel->duty_0 = A1 + A2 + B0 + B1 + B2;

	/* saturation operation here */
	if(outputChannel->duty_0 > outputChannel->duty_max)
	{
		outputChannel->duty_0 = outputChannel->duty_max;
	}
	else if(outputChannel->duty_0 < outputChannel->duty_min)
	{
		outputChannel->duty_0 = outputChannel->duty_min;
	}

	/* update the data buffer of the channel */
	outputChannel->duty_2 = outputChannel->duty_1;
	outputChannel->duty_1 = outputChannel->duty_0;

	outputChannel->error_2 = outputChannel->error_1;
	outputChannel->error_1 = outputChannel->error_0;
	/* error_0 to be updated in the ADC ISR*/
}

void ControllerLeadLag(float32* output, float32 * errorArray, Uint16 errorArrayCounter, float32* outputArray, Uint16 outputArrayCounter)
{
	//u(n) = a1* u(n - 1) + a2 * u(n - 2) + b0 * e(n) + b1 * e(n - 1) + b2 * e(n - 2);
	float32 A1, A2, B0, B1, B2;
	Uint16 counter_1, counter_2, counter_0;
	if(outputArrayCounter == 0)
	{
		counter_1 = 30;
		counter_2 = 29;
	}
	else if(outputArrayCounter == 1)
	{
		counter_1 = 0;
		counter_2 = 30;
	}
	else
	{
		counter_1 = outputArrayCounter - 1;
		counter_2 = outputArrayCounter - 2;
	}
	counter_0 = outputArrayCounter;

	A1 = (float32)Coefficient_a1 * outputArray[counter_1];
	A2 = (float32)Coefficient_a2 * outputArray[counter_2];
	B0 = (float32)Coefficient_b0 * errorArray[counter_0];
	B1 = (float32)Coefficient_b1 * errorArray[counter_1];
	B2 = (float32)Coefficient_b2 * errorArray[counter_2];

	*output = A1 + A2 + B0 + B1 + B2;

//	output = (Coefficient_a1 * outputArray[outputArrayCounter - 1]) + (Coefficient_a2 * outputArray[outputArrayCounter - 2]) + (Coefficient_b0 * errorArray[errorArrayCounter]) + (Coefficient_b1 * errorArray[errorArrayCounter - 1]) + (Coefficient_b2 * errorArray[errorArrayCounter - 2]);

}

void ControllerPid(PID_CONTROLLER* pControlData)
{
//	PID_MACRO(controlData);
	/* proportional term */
	pControlData->data.up = _IQmpy(pControlData->param.Kr, pControlData->term.Ref) - pControlData->term.Fbk;
//	pControlData->data.up = (pControlData->param.Kr * pControlData->term.Ref)>>14U - pControlData->term.Fbk;

	/* integral term */
	pControlData->data.ui = _IQmpy(pControlData->param.Ki, _IQmpy(pControlData->data.w1, (pControlData->term.Ref - pControlData->term.Fbk))) + pControlData->data.i1;
	pControlData->data.i1 = pControlData->data.ui;

	/* derivative term */
	pControlData->data.d2 = _IQmpy(pControlData->param.Kd, _IQmpy(pControlData->term.c1, (_IQmpy(pControlData->term.Ref, pControlData->param.Km) - pControlData->term.Fbk))) - pControlData->data.d2;
	pControlData->data.ud = pControlData->data.d2 + pControlData->data.d1;
	pControlData->data.d1 = _IQmpy(pControlData->data.ud, pControlData->term.c2);

	/* control output */
	pControlData->data.v1 = _IQmpy(pControlData->param.Kp, (pControlData->data.up + pControlData->data.ui + pControlData->data.ud));
	pControlData->term.Out= _IQsat(pControlData->data.v1, pControlData->param.Umax, pControlData->param.Umin);
	pControlData->data.w1 = (pControlData->term.Out == pControlData->data.v1) ? _IQ(1.0) : _IQ(0.0);

}
