#include "DSP2803x_Device.h"     // DSP28 Headerfile Include File
#include "DSP2803x_Examples.h"   // DSP28 Examples Include File
#include "eCAN.h"


/* This function shall be called after calling InitECan(); */
void eCANConfigRXMailbox(Uint16 mailBox, Uint16 identifier, Uint16 mask, Uint16 dataProtection, Uint16 interruptEnable, Uint16 interruptLine)
{
    EALLOW;
    struct ECAN_REGS ECanaShadow;

    /* 1. Disable mailbox by clearing CANME bit */
    ECanaShadow.CANME.all = ECanaRegs.CANME.all;
    ECanaShadow.CANME.all = ECanaShadow.CANME.all & (0xFFFFFFFF ^ (0x01 << mailBox));

    ECanaRegs.CANME.all = ECanaShadow.CANME.all;

    /* 2. Write the selected identifier into the corresponding MSGID register */
    /* supports only standard ID */
    ECanaMboxes.MBOX[mailBox].MSGID.bit.IDE = 0U;	//use standard IDs
    ECanaMboxes.MBOX[mailBox].MSGID.bit.STDMSGID = identifier;
    ECanaMboxes.MBOX[mailBox].MSGID.bit.EXTMSGID_L = 0U;
    ECanaMboxes.MBOX[mailBox].MSGID.bit.EXTMSGID_H = 0U;

    ECanaMboxes.MBOX[mailBox].MSGID.bit.AAM = 0U;	//Disable auto answer.


    /* 3. Set mask for acceptance */
    if(0U == mask)  /* user disables acceptance mask function */
    {
        ECanaMboxes.MBOX[mailBox].MSGID.bit.AME = 0U;           /* disable acceptance mask function */
    }
    else            /* user enables acceptance mask function */
    {
        ECanaMboxes.MBOX[mailBox].MSGID.bit.AME = 1U;           /* enable acceptance mask function */
        ECanaLAMRegs.LAM[mailBox].bit.LAMI = 1U;                /* acceptance active ??? */
        ECanaLAMRegs.LAM[mailBox].bit.LAM_H = (mask << 2U);     /* set mask for standard 11 bit ID */
    }

    /* 4. Configure the mailbox as a receive mailbox */
    ECanaShadow.CANMD.all = ECanaRegs.CANMD.all;
    ECanaShadow.CANMD.all |= (1U << mailBox);
    ECanaRegs.CANMD.all = ECanaShadow.CANMD.all;

    /* 5. Set data protection for the mailbox */
    ECanaShadow.CANOPC.all = ECanaRegs.CANOPC.all;
    if(Enable_Data_Protection == dataProtection)
    {
    	ECanaShadow.CANOPC.all |= (1U << mailBox);                /* set corresponding bit */
    }
    else
    {
    	ECanaShadow.CANOPC.all &= (0xFFFFFFFFU ^ (1U << mailBox));/* clear corresponding bit */
    }
    ECanaRegs.CANOPC.all = ECanaShadow.CANOPC.all;

    /* 6. enable mailbox */
    /* to be done by calling eCANEnableMailbox(); */

    /* 7. configure interrupt of the mailbox */
    ECanaShadow.CANMIM.all = ECanaRegs.CANMIM.all;
    if(Enable_Interrupt == interruptEnable)
    {
    	ECanaShadow.CANMIM.all |= (1U << mailBox);                /* set corresponding bit */
    }
    else
    {
    	ECanaShadow.CANMIM.all &= (0xFFFFFFFFU ^ (1U << mailBox));/* clear corresponding bit */
    }
    ECanaRegs.CANMIM.all = ECanaShadow.CANMIM.all;

    ECanaShadow.CANMIL.all = ECanaRegs.CANMIL.all;
    if(Interrupt_Line_1 == interruptLine)
    {
    	ECanaShadow.CANMIL.all |= (1U << mailBox);                /* set corresponding bit */
    }
    else
    {
    	ECanaShadow.CANMIL.all &= (0xFFFFFFFFU ^ (1U << mailBox));/* clear corresponding bit */
    }
    ECanaRegs.CANMIL.all = ECanaShadow.CANMIL.all;

    /* 5. Enable the mail box */
    ECanaShadow.CANME.all = ECanaRegs.CANME.all;
    ECanaShadow.CANME.all |= (1U << mailBox);
    ECanaRegs.CANME.all = ECanaShadow.CANME.all;

    EDIS;
}

/* This function shall be called after calling InitECan(); */
void eCANConfigTXMailbox(Uint16 mailBox, Uint16 interruptEnable, Uint16 interruptLine)
{
    EALLOW;

    struct ECAN_REGS ECanaShadow;

    /* 1. Clear the corresponding CANTRS bit of the mailbox */
    /* stop/prevent transmission operation */

    do{
    	ECanaShadow.CANTRR.all = ECanaRegs.CANTRR.all;
    	ECanaShadow.CANTRR.all |= (1U << mailBox);
    	ECanaRegs.CANTRR.all = ECanaShadow.CANTRR.all;

    }while((ECanaRegs.CANTRS.all)&(1U << mailBox));

    ECanaShadow.CANAA.all = ECanaRegs.CANAA.all;
    ECanaShadow.CANAA.all |= (1U << mailBox);
    ECanaRegs.CANAA.all = ECanaShadow.CANAA.all;	//clear AA bit which is not set by intension.

    /* 2. Disable the mailbox */
    ECanaShadow.CANME.all = ECanaRegs.CANME.all;
    ECanaShadow.CANME.all &= (0xFFFFFFFFU ^ (1U << mailBox));     /* clear corresponding bit */
    ECanaRegs.CANME.all = ECanaShadow.CANME.all;

    /* 3. Set up mailbox properties */
    ECanaMboxes.MBOX[mailBox].MSGID.bit.AME = 0U;               /* clear acceptance mask (this function is for receive only) */
    ECanaMboxes.MBOX[mailBox].MSGID.bit.AAM = 0U;               /* clear automatic answer (this function is for receive only) */
    ECanaMboxes.MBOX[mailBox].MSGID.bit.IDE = 0U;				/* send standard ID only */

    ECanaShadow.CANMD.all = ECanaRegs.CANMD.all;
    ECanaShadow.CANMD.all &= (0xFFFFFFFFU ^ (1U << mailBox));     /* set the mail box direction to transmit */
    ECanaRegs.CANMD.all = ECanaShadow.CANMD.all;

    /* 4. Configure interrupt for the mail box */
    ECanaShadow.CANMIM.all = ECanaRegs.CANMIM.all;
    if(Enable_Interrupt == interruptEnable)
    {
    	ECanaShadow.CANMIM.all |= (1U << mailBox);                /* set corresponding bit */
    }
    else
    {
    	ECanaShadow.CANMIM.all &= (0xFFFFFFFFU ^ (1U << mailBox));/* clear corresponding bit */
    }
    ECanaRegs.CANMIM.all = ECanaShadow.CANMIM.all;

    ECanaShadow.CANMIL.all = ECanaRegs.CANMIL.all;
    if(Interrupt_Line_1 == interruptLine)
    {
    	ECanaShadow.CANMIL.all |= (1U << mailBox);                /* set corresponding bit */
    }
    else
    {
    	ECanaShadow.CANMIL.all &= (0xFFFFFFFFU ^ (1U << mailBox));/* clear corresponding bit */
    }
    ECanaRegs.CANMIL.all = ECanaShadow.CANMIL.all;

    /* 5. Enable the mail box */
    ECanaShadow.CANME.all = ECanaRegs.CANME.all;
	ECanaShadow.CANME.all |= (1U << mailBox);
	ECanaRegs.CANME.all = ECanaShadow.CANME.all;

    EDIS;
}

/* this function enables a single selected mailbox */
/* this function shall be called after the mailbox is properly configured */
void eCANEnableMailbox(Uint16 mailBox)
{
    EALLOW;
    struct ECAN_REGS ECanaShadow;
    ECanaShadow.CANME.all = ECanaRegs.CANME.all;

    ECanaShadow.CANME.all |= (1U << mailBox);

    ECanaRegs.CANME.all = ECanaShadow.CANME.all;

    EDIS;
}

/* this function disables a single selected mailbox */
/* this function shall be called after the mailbox is properly configured */
void eCANDisableMailbox(Uint16 mailBox)
{
	EALLOW;
	struct ECAN_REGS ECanaShadow;
	ECanaShadow.CANME.all = ECanaRegs.CANME.all;

	ECanaShadow.CANME.all &= 0xffffffff ^ (1U << mailBox);

    ECanaRegs.CANME.all = ECanaShadow.CANME.all;

    EDIS;
}

/* this function enables the global interrupt of the eCAN module on the selected interrupt line */
/* this function shall be called after mailboxes are properly configured */
void eCANEnableNotification(Uint16 interruptLine)
{
    EALLOW;
	struct ECAN_REGS ECanaShadow;
    /* interrupt types are configured while eCAN initialization */
	ECanaShadow.CANGIM.all = ECanaRegs.CANGIM.all;
	ECanaShadow.CANGIM.all |= interruptLine;
	ECanaRegs.CANGIM.all = ECanaShadow.CANGIM.all;

    EDIS;
}

/* this function disables the global interrupt of the eCAN module on the selected interrupt line */
void eCANDisableNotification(Uint16 interruptLine)
{
    EALLOW;
    struct ECAN_REGS ECanaShadow;
    /* interrupt types are configured while eCAN initialization */
    ECanaShadow.CANGIM.all = ECanaRegs.CANGIM.all;
    ECanaRegs.CANGIM.all &= (0xFFFFFFFFU ^ interruptLine);
    ECanaRegs.CANGIM.all = ECanaShadow.CANGIM.all;

    EDIS;
}

void eCANTransmitData(Uint16 mailBox, eCAN_Data_t* data)
{
    EALLOW;
    struct ECAN_REGS ECanaShadow;

    do{
    	ECanaShadow.CANTA.all = ECanaRegs.CANTA.all;
    	ECanaShadow.CANTA.all |= 0x01U << mailBox;
    	ECanaRegs.CANTA.all = ECanaShadow.CANTA.all;

    }while(ECanaRegs.CANTA.all & (0x01U << mailBox));	// clear TA if it is set.

    eCANDisableMailbox(mailBox);

    /* 1. set DLC */
    ECanaMboxes.MBOX[mailBox].MSGCTRL.bit.DLC = data->length;

    /* 2. set priority */
    ECanaMboxes.MBOX[mailBox].MSGCTRL.bit.TPL = data->priority;

    /* 3. set identifier */
    /* supports only standard identifier */
    //ECanaMboxes.MBOX[mailBox].MSGID.bit.STDMSGID = data->identifier.standard;
    ECanaMboxes.MBOX[mailBox].MSGID.bit.AAM = 0U;
    ECanaMboxes.MBOX[mailBox].MSGID.bit.AME = 0U;	//clear these 2 bits as described in the user's manual

//ECanaMboxes.MBOX[mailBox].MSGID.bit.EXTMSGID_L = (Uint16)(data->identifier.extended & 0x0000ffff);
//ECanaMboxes.MBOX[mailBox].MSGID.bit.EXTMSGID_H = (Uint16)((data->identifier.extended >> 16U) & 0x0000ffff);
    ECanaMboxes.MBOX[mailBox].MSGID.bit.STDMSGID = data->identifier.standard;
    ECanaMboxes.MBOX[mailBox].MSGID.bit.EXTMSGID_L = 0U;
    ECanaMboxes.MBOX[mailBox].MSGID.bit.EXTMSGID_H = 0U;

    eCANEnableMailbox(mailBox);

    /* 4. set data to mailbox */
    /* DBO = 0, MSByte first */
    ECanaMboxes.MBOX[mailBox].MDL.byte.BYTE0 = data->byte[0];
    ECanaMboxes.MBOX[mailBox].MDL.byte.BYTE1 = data->byte[1];
    ECanaMboxes.MBOX[mailBox].MDL.byte.BYTE2 = data->byte[2];
    ECanaMboxes.MBOX[mailBox].MDL.byte.BYTE3 = data->byte[3];
    ECanaMboxes.MBOX[mailBox].MDH.byte.BYTE4 = data->byte[4];
    ECanaMboxes.MBOX[mailBox].MDH.byte.BYTE5 = data->byte[5];
    ECanaMboxes.MBOX[mailBox].MDH.byte.BYTE6 = data->byte[6];
    ECanaMboxes.MBOX[mailBox].MDH.byte.BYTE7 = data->byte[7];

    /* 5. trigger transmission */

    ECanaShadow.CANTRS.all  = ECanaRegs.CANTRS.all;
    ECanaShadow.CANTRS.all |= (0x01U << mailBox); //Trigger transmission by setting the TRS bit.
    ECanaRegs.CANTRS.all  = ECanaShadow.CANTRS.all;

    EDIS;

}

//Get data from CAN module
//Get only one data out from the CAN
Uint16 eCANGetData(Uint16 mailBox, eCAN_Data_t* receivedData)
{
	Uint16 success;
	Uint32 RecieveMessagePendingFlags;

	EALLOW;

	success = 0U;
	RecieveMessagePendingFlags = ECanaRegs.CANRMP.all;
	if(RecieveMessagePendingFlags & (0x01 << mailBox))	//check whether the mailbox has message available.
	{
		RecieveMessagePendingFlags = 0x01<<mailBox;
		ECanaRegs.CANRMP.all = RecieveMessagePendingFlags;

		receivedData->identifier.standard = ECanaMboxes.MBOX[mailBox].MSGID.bit.STDMSGID;
		receivedData->byte[0] =  ECanaMboxes.MBOX[mailBox].MDL.byte.BYTE0;
		receivedData->byte[1] =  ECanaMboxes.MBOX[mailBox].MDL.byte.BYTE1;
		receivedData->byte[2] =  ECanaMboxes.MBOX[mailBox].MDL.byte.BYTE2;
		receivedData->byte[3] =  ECanaMboxes.MBOX[mailBox].MDL.byte.BYTE3;
		receivedData->byte[4] =  ECanaMboxes.MBOX[mailBox].MDH.byte.BYTE4;
		receivedData->byte[5] =  ECanaMboxes.MBOX[mailBox].MDH.byte.BYTE5;
		receivedData->byte[6] =  ECanaMboxes.MBOX[mailBox].MDH.byte.BYTE6;
		receivedData->byte[7] =  ECanaMboxes.MBOX[mailBox].MDH.byte.BYTE7;

		success = 1U;
		EDIS;

		return success;
	}
	else
	{
		EDIS;
		//no data pending in the mailbox
		return success;
	}
}
