/* TI File $Revision: /main/1 $												*/
/* Checkin $Date: 15th Mar, 2013 $											*/
/****************************************************************************/
/*																			*/
/* FILE:	ePWM.c															*/
/*																			*/
/* TITLE:	DSP28032/5 ePWM module low level drivers 						*/
/*																			*/
/* This file contains low level drivers of ePWM modules dedicated for		*/
/* SAE LED project.															*/
/*																			*/
/*																			*/
/****************************************************************************/
/* $Release Date: $															*/
/****************************************************************************/

#include "DSP2803x_Device.h"
#include "DSP2803x_Examples.h"
#include "IQMathLib.h"
#include "SQMath.h"
#include "ePWM.h"
#include "sys_config.h"


#pragma CODE_SECTION(ePwmSetBoostAHRDuty_IQ, "ramfuncs");
#pragma CODE_SECTION(ePwmSetBoostBHRDuty_IQ, "ramfuncs");


// Used to indirectly access all EPWM modules, very useful!
volatile struct EPWM_REGS *ePWM[] =
                  { &EPwm1Regs,         //intentional (ePWM[0] not used)
                    &EPwm1Regs,
                    &EPwm2Regs,
                    &EPwm3Regs,
                    &EPwm4Regs,
                    &EPwm5Regs,
                    &EPwm6Regs,
                    #ifdef DSP2803x_DEVICE_H
                    &EPwm7Regs,
                    #endif
                  };

#define EPWMxREG_BASEADDRESS    0x006800
#define EPWMxREG_MODULE_OFFSET  0x40

/* for fast access to peripheral registers */
#define EPWM1A_REG_POINTER_CMPAHR		(*(volatile Uint16*)0x6808)
#define EPWM1A_REG_POINTER_CMPA			(*(volatile Uint16*)0x6809)
#define EPWM1B_REG_POINTER_CMPB			(*(volatile Uint16*)0x680A)

#define EPWM2A_REG_POINTER_CMPA			(*(volatile Uint16*)0x6849)
#define EPWM2B_REG_POINTER_CMPB			(*(volatile Uint16*)0x684A)

#define EPWM4A_REG_POINTER_CMPA			(*(volatile Uint16*)0x68C9)
#define EPWM4B_REG_POINTER_CMPB			(*(volatile Uint16*)0x68CA)

#define EPWM3A_REG_POINTER_CMPAHR		(*(volatile Uint16*)0x6888)
#define EPWM3A_REG_POINTER_CMPA			(*(volatile Uint16*)0x6889)

#define EPWM5A_REG_POINTER_CMPAHR		(*(volatile Uint16*)0x6908)
#define EPWM5A_REG_POINTER_CMPA			(*(volatile Uint16*)0x6909)


void ePwmInit( void )
{
    //// Initialization of ePWM modules for normal operation
    /* TB frequency is set to 60MHz, */
    // = = = = = = = = = = = = = = = = = = = = = = = =

#ifdef __ENABLE_BUCK__
    /* Buck, normal speed normal resolution PWM         */
    /* EPWM1 is used for LED channel A=1, B=4           */
    /* Target PWM frequency = 300KHz                    */
    /* PWM phase shift A = -120 degree , B = 60 degree  */
    EALLOW;

//    EPwm1Regs.TBPRD = 100;                          // Period = 100 * 2 TBCLK counts in symmetric, which is 300KHz
    EPwm1Regs.TBPRD = EPWM1_PERIOD_COUNT;                          // Period = 200 * 2 TBCLK counts in symmetric, which is 150KHz

//    EPwm1Regs.CMPA.half.CMPA = 50;                   // Compare A = 0 TBCLK counts
    EPwm1Regs.CMPA.half.CMPA = EPWM1_PERIOD_COUNT/2;                   // Compare A = 0 TBCLK counts

    EPwm1Regs.CMPB = EPWM1_PERIOD_COUNT;                             // Compare B = 0 TBCLK counts
//    EPwm1Regs.TBPHS.half.TBPHS  = EPWM1_PERIOD_COUNT*2/3;              // Set Phase register to period/3, A: 120 degrees in advance; B: 60 degrees behind

    EPwm1Regs.TBCTR = 0;                            // clear TB counter
    EPwm1Regs.TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN;  // count up-down mode, symmetric PWM

    EPwm1Regs.TBCTL.bit.PHSEN = TB_ENABLE;          // Phase loading enabled

    EPwm1Regs.TBCTL.bit.PRDLD = TB_SHADOW;          // PWM update is shadowed, not immediate effective
    EPwm1Regs.TBCTL.bit.SYNCOSEL = TB_SYNC_IN;      // SWFSYNC is valid (operates) only when EPWMxSYNCI is selected by SYNCOSEL = 00.

    EPwm1Regs.TBCTL.bit.HSPCLKDIV = TB_DIV1;        // TBCLK = SYSCLK @ 60MHz
    EPwm1Regs.TBCTL.bit.CLKDIV = TB_DIV1;

    EPwm1Regs.CMPCTL.bit.SHDWAMODE = CC_SHADOW;
    EPwm1Regs.CMPCTL.bit.SHDWBMODE = CC_SHADOW;
    EPwm1Regs.CMPCTL.bit.LOADAMODE = CC_CTR_ZERO;   // load on CTR = Zero
    EPwm1Regs.CMPCTL.bit.LOADBMODE = CC_CTR_ZERO;   // load on CTR = Zero

    // ePWM1A duty polarity is high, duty in-middle output
    EPwm1Regs.AQCTLA.bit.ZRO = AQ_CLEAR;
    EPwm1Regs.AQCTLA.bit.CAU = AQ_SET;
    EPwm1Regs.AQCTLA.bit.CAD = AQ_CLEAR;
    EPwm1Regs.AQCTLA.bit.PRD = AQ_NO_ACTION;

    // ePWM1B duty polarity is high, duty in-middle output
    EPwm1Regs.AQCTLB.bit.ZRO = AQ_CLEAR;
    EPwm1Regs.AQCTLB.bit.CBU = AQ_SET;
    EPwm1Regs.AQCTLB.bit.CBD = AQ_CLEAR;
    EPwm1Regs.AQCTLB.bit.PRD = AQ_NO_ACTION;


//    //configure the HRPWM resources, Not used in this projects
//    EPwm1Regs.HRCNFG.all = 0x0;                 // clear all bits first
//    EPwm1Regs.HRCNFG.bit.EDGMODE = HR_FEP;      // Control Falling Edge Position
//    EPwm1Regs.HRCNFG.bit.CTLMODE = HR_CMP;      // CMPAHR controls the MEP
//    EPwm1Regs.HRCNFG.bit.HRLOAD = HR_CTR_ZERO;  // Shadow load on CTR=Zero

    /* ADC trigger on ePWM1 */
    EPwm1Regs.ETSEL.bit.SOCASEL = ET_CTR_PRD;       // PWM1 SOCA on period event, ADC trigger at mid point of PWM duty
    EPwm1Regs.ETPS.bit.SOCAPRD = ET_3RD;            // Trigger on every 3rd event
    EPwm1Regs.ETSEL.bit.SOCAEN = 1;                 // Enable PWM1 SOCA, for SOC4

    EPwm1Regs.ETSEL.bit.SOCBSEL = ET_CTR_PRD;       // PWM1 SOCB on period event, ADC trigger at mid point of PWM duty
    EPwm1Regs.ETPS.bit.SOCBPRD = ET_3RD;            // Trigger on every 3rd event
    EPwm1Regs.ETSEL.bit.SOCBEN = 1;                 // Enable PWM1 SOCB, for SOC5

    EDIS;


    /* Buck, normal speed normal resolution PWM         */
    /* EPWM2 is used for LED channel A=2, B=5           */
    /* Target PWM frequency = 300KHz                    */
    /* PWM phase shift A = -60 degree , B = 120 degree  */
    EALLOW;

    EPwm2Regs.TBPRD = EPWM2_PERIOD_COUNT;                         // Period = 100*2 TBCLK counts, which is 300KHz
    EPwm2Regs.CMPA.half.CMPA = EPWM2_PERIOD_COUNT/2;                  // Compare A = 100 TBCLK counts
    EPwm2Regs.CMPB = EPWM2_PERIOD_COUNT/2;                            // Compare B = 100 TBCLK counts
//    EPwm2Regs.TBPHS.half.TBPHS = EPWM2_PERIOD_COUNT/3;               // Set Phase register to period/6, A: 60 degrees in advance; B: 120 degrees behind

    EPwm2Regs.TBCTR = 0;                            // clear TB counter
    EPwm2Regs.TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN;  // count up-down mode, symmetric PWM

    EPwm2Regs.TBCTL.bit.PHSEN = TB_ENABLE;          // Phase loading enabled

    EPwm2Regs.TBCTL.bit.PRDLD = TB_SHADOW;          // PWM update is shadowed, not immediate effective
//    EPwm2Regs.TBCTL.bit.PRDLD = TB_IMMEDIATE;
    EPwm2Regs.TBCTL.bit.SYNCOSEL = TB_SYNC_IN;      //SWFSYNC is valid (operates) only when EPWMxSYNCI is selected by SYNCOSEL = 00.

    EPwm2Regs.TBCTL.bit.HSPCLKDIV = TB_DIV1;        // TBCLK = SYSCLK
    EPwm2Regs.TBCTL.bit.CLKDIV = TB_DIV1;

    EPwm2Regs.CMPCTL.bit.SHDWAMODE = CC_SHADOW;
    EPwm2Regs.CMPCTL.bit.SHDWBMODE = CC_SHADOW;
    EPwm2Regs.CMPCTL.bit.LOADAMODE = CC_CTR_ZERO;   // load on CTR = Zero
    EPwm2Regs.CMPCTL.bit.LOADBMODE = CC_CTR_ZERO;   // load on CTR = Zero

    // ePWM2A duty polarity is high, duty in-middle output
    EPwm2Regs.AQCTLA.bit.ZRO = AQ_CLEAR;
    EPwm2Regs.AQCTLA.bit.CAU = AQ_SET;
    EPwm2Regs.AQCTLA.bit.CAD = AQ_CLEAR;
    EPwm2Regs.AQCTLA.bit.PRD = AQ_NO_ACTION;

    // ePWM2B duty polarity is high, duty in-middle output
    EPwm2Regs.AQCTLB.bit.ZRO = AQ_CLEAR;
    EPwm2Regs.AQCTLB.bit.CBU = AQ_SET;
    EPwm2Regs.AQCTLB.bit.CBD = AQ_CLEAR;
    EPwm2Regs.AQCTLB.bit.PRD = AQ_NO_ACTION;

    //configure the HRPWM resources
//    EPwm2Regs.HRCNFG.all = 0x0;                   // clear all bits first
//    EPwm2Regs.HRCNFG.bit.EDGMODE = HR_FEP;        // Control Falling Edge Position
//    EPwm2Regs.HRCNFG.bit.CTLMODE = HR_CMP;        // CMPAHR controls the MEP
//    EPwm2Regs.HRCNFG.bit.HRLOAD = HR_CTR_ZERO;    // Shadow load on CTR=Zero

    /* ADC trigger on ePWM2 */
    EPwm2Regs.ETSEL.bit.SOCASEL = ET_CTR_PRD;       // PWM2 SOCA on period event, ADC trigger at mid point of PWM duty
    EPwm2Regs.ETPS.bit.SOCAPRD = ET_3RD;            // Trigger on every 3rd event
    EPwm2Regs.ETSEL.bit.SOCAEN = 1;                 // Enable PWM2 SOCA, for SOC6

    EPwm2Regs.ETSEL.bit.SOCBSEL = ET_CTR_PRD;       // PWM1 SOCB on period event, ADC trigger at mid point of PWM duty
    EPwm2Regs.ETPS.bit.SOCBPRD = ET_3RD;            // Trigger on every 3rd event
    EPwm2Regs.ETSEL.bit.SOCBEN = 1;                 // Enable PWM2 SOCB, for SOC7

    EDIS;

    /* Buck, normal speed normal resolution PWM         */
    /* EPWM4 is used for LED channel A=3, B=6           */
    /* Target PWM frequency = 300KHz                    */
    /* PWM phase shift A = 0 degree , B = 180 degree    */
    EALLOW;

    EPwm4Regs.TBPRD = EPWM4_PERIOD_COUNT;                         // Period = 100*2 TBCLK counts, which is 300KHz
    EPwm4Regs.CMPA.half.CMPA = EPWM4_PERIOD_COUNT/2;                  // Compare A = 100 TBCLK counts
    EPwm4Regs.CMPB = EPWM4_PERIOD_COUNT/2;                            // Compare B = 100 TBCLK counts
    EPwm4Regs.TBPHS.half.TBPHS = EPWM4_PERIOD_COUNT;                // Set Phase register to period/6, A: 60 degrees in advance; B: 120 degrees behind

    EPwm4Regs.TBCTR = 0;                            // clear TB counter
    EPwm4Regs.TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN;  // count up-down mode, symmetric PWM

    EPwm4Regs.TBCTL.bit.PHSEN = TB_ENABLE;         // Phase loading enabled

    EPwm4Regs.TBCTL.bit.PRDLD = TB_SHADOW;          // PWM update is shadowed, not immediate effective
//    EPwm2Regs.TBCTL.bit.PRDLD = TB_IMMEDIATE;
    EPwm4Regs.TBCTL.bit.SYNCOSEL = TB_SYNC_IN;      //SWFSYNC is valid (operates) only when EPWMxSYNCI is selected by SYNCOSEL = 00.

    EPwm4Regs.TBCTL.bit.HSPCLKDIV = TB_DIV1;        // TBCLK = SYSCLK
    EPwm4Regs.TBCTL.bit.CLKDIV = TB_DIV1;

    EPwm4Regs.CMPCTL.bit.SHDWAMODE = CC_SHADOW;
    EPwm4Regs.CMPCTL.bit.SHDWBMODE = CC_SHADOW;
    EPwm4Regs.CMPCTL.bit.LOADAMODE = CC_CTR_ZERO;   // load on CTR = Zero
    EPwm4Regs.CMPCTL.bit.LOADBMODE = CC_CTR_ZERO;   // load on CTR = Zero

    // ePWM4A duty polarity is high, duty in-middle output
    EPwm4Regs.AQCTLA.bit.ZRO = AQ_CLEAR;
    EPwm4Regs.AQCTLA.bit.CAU = AQ_SET;
    EPwm4Regs.AQCTLA.bit.CAD = AQ_CLEAR;
    EPwm4Regs.AQCTLA.bit.PRD = AQ_NO_ACTION;

    // ePWM4B duty polarity is high, duty in-middle output
    EPwm4Regs.AQCTLB.bit.ZRO = AQ_CLEAR;
    EPwm4Regs.AQCTLB.bit.CBU = AQ_SET;
    EPwm4Regs.AQCTLB.bit.CBD = AQ_CLEAR;
    EPwm4Regs.AQCTLB.bit.PRD = AQ_NO_ACTION;

    //configure the HRPWM resources
//    EPwm4Regs.HRCNFG.all = 0x0;                 // clear all bits first
//    EPwm4Regs.HRCNFG.bit.EDGMODE = HR_FEP;      // Control Falling Edge Position
//    EPwm4Regs.HRCNFG.bit.CTLMODE = HR_CMP;      // CMPAHR controls the MEP
//    EPwm4Regs.HRCNFG.bit.HRLOAD = HR_CTR_ZERO;  // Shadow load on CTR=Zero

    /* ADC trigger on ePWM4 */
    EPwm4Regs.ETSEL.bit.SOCASEL = ET_CTR_PRD;       // PWM4 SOCA on period event, ADC trigger at mid point of PWM duty
    EPwm4Regs.ETPS.bit.SOCAPRD = ET_3RD;            // Trigger on every 3rd event
    EPwm4Regs.ETSEL.bit.SOCAEN = 1;                 // Enable PWM4 SOCA, for SOC8

    EPwm4Regs.ETSEL.bit.SOCBSEL = ET_CTR_PRD;       // PWM1 SOCB on period event, ADC trigger at mid point of PWM duty
    EPwm4Regs.ETPS.bit.SOCBPRD = ET_3RD;            // Trigger on every 3rd event
    EPwm4Regs.ETSEL.bit.SOCBEN = 1;                 // Enable PWM4 SOCB, for SOC9

    EDIS;

#endif //__ENABLE_BUCK__

    /* Boost channel 2, high speed high resolution PWM  */
    /* EPWM3 is used for LED channel A=PWM2A, B=PWM2B   */
    /* Target PWM frequency = 500KHz                    */
    /* PWM phase shift A = 0 degree , B = 0 degree      */
    EALLOW;

    EPwm3Regs.TBPRD = EPWM3_PERIOD_COUNT;           // Period = 120 TBCLK counts, which is 500KHz
    EPwm3Regs.CMPA.half.CMPA = 0U;                  // Compare A = 60 TBCLK counts
    EPwm3Regs.CMPB = 0U;                            // Compare B = 60 TBCLK counts
    EPwm3Regs.TBPHS.half.TBPHS = 0U;                // Set Phase register to 0

    EPwm3Regs.TBCTR = 0;                            // clear TB counter
    EPwm3Regs.TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN;  // count-up-down mode, symmetric

    EPwm3Regs.TBCTL.bit.PHSEN = TB_DISABLE;         // Phase loading disabled

    EPwm3Regs.TBCTL.bit.PRDLD = TB_SHADOW;          // PWM update is shadowed, not immediate effective
    //    EPwm2Regs.TBCTL.bit.PRDLD = TB_IMMEDIATE;
    EPwm3Regs.TBCTL.bit.SYNCOSEL = TB_SYNC_DISABLE; //SWFSYNC is valid (operates) only when EPWMxSYNCI is selected by SYNCOSEL = 00.

    EPwm3Regs.TBCTL.bit.HSPCLKDIV = TB_DIV1;        // TBCLK = SYSCLK
    EPwm3Regs.TBCTL.bit.CLKDIV = TB_DIV1;

    EPwm3Regs.CMPCTL.bit.SHDWAMODE = CC_SHADOW;
    EPwm3Regs.CMPCTL.bit.SHDWBMODE = CC_SHADOW;
    EPwm3Regs.CMPCTL.bit.LOADAMODE = CC_CTR_ZERO;   // load on CTR = Zero
    EPwm3Regs.CMPCTL.bit.LOADBMODE = CC_CTR_ZERO;   // load on CTR = Zero

    EPwm3Regs.AQCTLA.bit.ZRO = AQ_CLEAR;              // ePWM3A duty polarity is high, duty first output
    EPwm3Regs.AQCTLA.bit.CAU = AQ_SET;

    EPwm3Regs.AQCTLA.bit.CAD = AQ_CLEAR;          // this is used only for sync boost (CMPB is used for EPWMB)
//    EPwm3Regs.AQCTLA.bit.CBD = AQ_CLEAR;            // CMPB can be used for EPWMA output
    EPwm3Regs.AQCTLA.bit.PRD = AQ_NO_ACTION;
//    EPwm3Regs.AQCTLB.bit.ZRO = AQ_CLEAR;          // ePWM3B has 180 degree phase shift from ePWM2A, shall add deadband
//    EPwm3Regs.AQCTLB.bit.CBU = AQ_SET;

#ifdef __ENABLE_SYNC_BOOST__
    EPwm3Regs.AQCTLB.bit.ZRO = AQ_SET;
    EPwm3Regs.AQCTLB.bit.CAU = AQ_CLEAR;
    EPwm3Regs.AQCTLB.bit.CAD = AQ_SET;          // this is used only for sync boost (CMPA is used for EPWMB)
    EPwm3Regs.AQCTLB.bit.PRD = AQ_NO_ACTION;

    EPwm3Regs.DBCTL.bit.HALFCYCLE = 1U;			//Half clock mode
    EPwm3Regs.DBCTL.bit.IN_MODE = 0U;			//EPWMA as the input for rise and fall edge
    EPwm3Regs.DBCTL.bit.POLSEL = DB_ACTV_HIC;	//Active high complementary (AHC). EPWMxB is inverted.
    EPwm3Regs.DBCTL.bit.OUT_MODE = DB_FULL_ENABLE;	//DB on EPWMA's rising edge and EPWMB's falling edge

    EPwm3Regs.DBRED = DEADBAND_HALF_CLOCK_COUNT;		//test
    EPwm3Regs.DBFED = DEADBAND_HALF_CLOCK_COUNT;


#endif /* __ENABLE_SYNC_BOOST__ */

    //configure the HRPWM resources
    EPwm3Regs.HRCNFG.all = 0x0;                     // clear all bits first
    EPwm3Regs.HRCNFG.bit.EDGMODE = HR_FEP;          // Control Falling Edge Position
    EPwm3Regs.HRCNFG.bit.CTLMODE = HR_CMP;          // CMPAHR controls the MEP
    EPwm3Regs.HRCNFG.bit.HRLOAD = HR_CTR_ZERO;      // Shadow load on CTR=Zero

    /* ADC trigger on ePWM3 */
    EPwm3Regs.ETSEL.bit.SOCASEL = ET_CTR_PRD;       // PWM3 SOCA on period event, ADC trigger at mid point of PWM duty
    EPwm3Regs.ETPS.bit.SOCAPRD = ET_3RD;            // Trigger on every 3rd event
    EPwm3Regs.ETSEL.bit.SOCAEN = 1;                 // Enable PWM3 SOCA, for SOC0/1

    EDIS;

    /* Boost channel 2, high speed high resolution PWM  */
    /* EPWM5 is used for LED channel A=PWM1A, B=PWM1B   */
    /* Target PWM frequency = 500KHz                    */
    /* PWM phase shift A = 0 degree , B = 0 degree      */
    EALLOW;

    EPwm5Regs.TBPRD = EPWM5_PERIOD_COUNT;           // Period = 120 TBCLK counts, which is 500KHz
    EPwm5Regs.CMPA.half.CMPA = 0U;                  // Compare A = 60 TBCLK counts
    EPwm5Regs.CMPB = 0U;                            // Compare B = 60 TBCLK counts
    EPwm5Regs.TBPHS.half.TBPHS = 0U;                // Set Phase register to 0

    EPwm5Regs.TBCTR = 0;                            // clear TB counter
    EPwm5Regs.TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN;  // count-up-down mode, symmetric

    EPwm5Regs.TBCTL.bit.PHSEN = TB_DISABLE;         // Phase loading disabled

    EPwm5Regs.TBCTL.bit.PRDLD = TB_SHADOW;          // PWM update is shadowed, not immediate effective
    //    EPwm2Regs.TBCTL.bit.PRDLD = TB_IMMEDIATE;
    EPwm5Regs.TBCTL.bit.SYNCOSEL = TB_SYNC_DISABLE; //SWFSYNC is valid (operates) only when EPWMxSYNCI is selected by SYNCOSEL = 00.

    EPwm5Regs.TBCTL.bit.HSPCLKDIV = TB_DIV1;        // TBCLK = SYSCLK
    EPwm5Regs.TBCTL.bit.CLKDIV = TB_DIV1;

    EPwm5Regs.CMPCTL.bit.SHDWAMODE = CC_SHADOW;
    EPwm5Regs.CMPCTL.bit.SHDWBMODE = CC_SHADOW;
    EPwm5Regs.CMPCTL.bit.LOADAMODE = CC_CTR_ZERO;   // load on CTR = Zero
    EPwm5Regs.CMPCTL.bit.LOADBMODE = CC_CTR_ZERO;   // load on CTR = Zero

    /* action setting for non-symetric pwm */
//    EPwm5Regs.AQCTLA.bit.ZRO = AQ_SET;              // ePWM5A duty polarity is high, duty first output
//    EPwm5Regs.AQCTLA.bit.CAU = AQ_CLEAR;
    /* --end of action setting for non-symetric pwm */

    /* action setting for symetric pwm */
    EPwm5Regs.AQCTLA.bit.ZRO = AQ_CLEAR;
    EPwm5Regs.AQCTLA.bit.CAU = AQ_SET;

    EPwm5Regs.AQCTLA.bit.CAD = AQ_CLEAR;          // this is used only for sync boost (CMPB is used for EPWMB)
//    EPwm5Regs.AQCTLA.bit.CBD = AQ_CLEAR;            // CMPB can be used for EPWMA output
    EPwm5Regs.AQCTLA.bit.PRD = AQ_NO_ACTION;
    /* --end of action setting for symetric pwm */

#ifdef __ENABLE_SYNC_BOOST__
    EPwm5Regs.AQCTLB.bit.ZRO = AQ_SET;
    EPwm5Regs.AQCTLB.bit.CAU = AQ_CLEAR;
    EPwm5Regs.AQCTLB.bit.CAD = AQ_SET;          // this is used only for sync boost (CMPA is used for EPWMB)
    EPwm5Regs.AQCTLB.bit.PRD = AQ_NO_ACTION;

    EPwm5Regs.DBCTL.bit.HALFCYCLE = 1U;			//Half clock mode
    EPwm5Regs.DBCTL.bit.IN_MODE = 0U;			//EPWMA as the input for rise and fall edge
    EPwm5Regs.DBCTL.bit.POLSEL = DB_ACTV_HIC;	//Active high complementary (AHC). EPWMxB is inverted.
    EPwm5Regs.DBCTL.bit.OUT_MODE = DB_FULL_ENABLE;	//DB on EPWMA's rising edge and EPWMB's falling edge

    EPwm5Regs.DBRED = DEADBAND_HALF_CLOCK_COUNT;		//test
    EPwm5Regs.DBFED = DEADBAND_HALF_CLOCK_COUNT;


#endif /* __ENABLE_SYNC_BOOST__ */

    //configure the HRPWM resources
    EPwm5Regs.HRCNFG.all = 0x0;                     // clear all bits first
    EPwm5Regs.HRCNFG.bit.EDGMODE = HR_FEP;          // Control Falling Edge Position
    EPwm5Regs.HRCNFG.bit.CTLMODE = HR_CMP;          // CMPAHR controls the MEP
    EPwm5Regs.HRCNFG.bit.HRLOAD = HR_CTR_ZERO;      // Shadow load on CTR=Zero

    /* ADC trigger on ePWM5 */
    EPwm5Regs.ETSEL.bit.SOCASEL = ET_CTR_PRD;       // PWM5 SOCA on period event, ADC trigger at mid point of PWM duty
    EPwm5Regs.ETPS.bit.SOCAPRD = ET_3RD;            // Trigger on every 3rd event
    EPwm5Regs.ETSEL.bit.SOCAEN = 1;                 // Enable PWM5 SOCA, for SOC2/3

    EDIS;

    /* initialize pins of ePWM modules */
#ifdef __ENABLE_BUCK__
//    InitEPwm1Gpio();
//    InitEPwm2Gpio();
//    InitEPwm4Gpio();
#endif //__ENABLE_BUCK__

#ifdef __ENABLE_BOOST__
//    InitEPwm3Gpio();
//    InitEPwm5Gpio();
#endif //__ENABLE_BOOST__
}

void ePwmStart(void)
{
    EALLOW;

#ifdef __ENABLE_BUCK__
    SysCtrlRegs.PCLKCR1.bit.EPWM1ENCLK = 1;     // ePWM1 DIM1, DIM4
    SysCtrlRegs.PCLKCR1.bit.EPWM2ENCLK = 1;     // ePWM2 DIM2, DIM5
    SysCtrlRegs.PCLKCR1.bit.EPWM4ENCLK = 1;     // ePWM4 DIM3, DIM6
#endif //__ENABLE_BUCK__

#ifdef __ENABLE_BOOST__
    SysCtrlRegs.PCLKCR1.bit.EPWM3ENCLK = 1;     // ePWM3 QB, QBsync
    SysCtrlRegs.PCLKCR1.bit.EPWM5ENCLK = 1;     // ePWM5 QA, QAsync
#endif //__ENABLE_BOOST__

    SysCtrlRegs.PCLKCR0.bit.TBCLKSYNC = 0;      // Clear TBCLK within the ePWM

#ifdef __ENABLE_BUCK__
    /* Trigger phase shift before trigger ePWM output to avoid instruction delay */
    EPwm1Regs.TBCTL.bit.SWFSYNC = 1;            // Trigger phase difference by SWSYNC bit
    EPwm2Regs.TBCTL.bit.SWFSYNC = 1;            // Trigger phase difference by SWSYNC bit
    EPwm4Regs.TBCTL.bit.SWFSYNC = 1;            // Trigger phase difference by SWSYNC bit
#endif //__ENABLE_BUCK__

    SysCtrlRegs.PCLKCR0.bit.TBCLKSYNC = 1;      // Enable TBCLK within the ePWM


    EDIS;

}


/* inline does not work ??!! */
/* inline works only when -O is specified. */

void ePwmSetPeriod(Uint16 module, Uint16 period)
{
    struct EPWM_REGS * pEPWMxReg;
    pEPWMxReg = (struct EPWM_REGS *)(EPWMxREG_BASEADDRESS + (EPWMxREG_MODULE_OFFSET * (module - 1)));   //point to the corresponding ePwm module register address

    EALLOW;

    pEPWMxReg->TBPRD = period;

    EDIS;

}
#if 0
void ePwmSetDuty(Uint16 module, Uint16 channel, Uint16 duty)
{
    struct EPWM_REGS * pEPWMxReg;
    Uint32 period;
    Uint16 duty_count;

    pEPWMxReg = (struct EPWM_REGS *)(EPWMxREG_BASEADDRESS + (EPWMxREG_MODULE_OFFSET * (module - 1)));   //point to the corresponding ePwm module register address

//    duty = 100 - duty;

    period = (Uint32) (pEPWMxReg->TBPRD);
    duty_count = (Uint16)(((period + 1) * duty)/100);
    duty_count = period + 1 - duty_count;       /* counting up and down mode */

    if(ChannelA == channel)
    {
        pEPWMxReg->CMPA.half.CMPA = duty_count;   //34 CPU cycles
        pEPWMxReg->CMPB = duty_count;
//        (*(volatile Uint16 *)(0x6849))= duty_count; //best efficiency with only 2 CPU cycles
    }
    else if(ChannelB == channel)
    {
        pEPWMxReg->CMPB = duty_count;
    }
    else
    {
        //error parameter "channel"
    }

}
#endif

//inline void ePwmSetNotification(Uint16 module, Uint16 int_type, Uint);
void ePwmEnableNotification(Uint16 module, Uint16 int_type, Uint16 int_count)
{
    struct EPWM_REGS * pEPWMxReg;
    pEPWMxReg = (struct EPWM_REGS *)(EPWMxREG_BASEADDRESS + (EPWMxREG_MODULE_OFFSET * (module - 1)));   //point to the corresponding ePwm module register address

    pEPWMxReg->ETCLR.bit.INT = 1;               //clear spurious ePwm interrupts
    pEPWMxReg->ETSEL.bit.INTSEL = int_type;     //set interrupt type
    pEPWMxReg->ETPS.bit.INTPRD = int_count;     //set interrupt period
    pEPWMxReg->ETSEL.bit.INTEN = 1;             //enable ePwm interrupt

}
#if 0
/* inline set up ePwm duty with High resolution function */
void ePwmSetHRDuty(Uint16 module, Uint16 channel, float32 duty)
{
	//cpu take 7 cycles to enter the function call
    struct EPWM_REGS * pEPWMxReg;
    Uint16 duty_HR;
    Uint32 duty_int;

//    pEPWMxReg = (struct EPWM_REGS *)(EPWMxREG_BASEADDRESS + (EPWMxREG_MODULE_OFFSET * (module - 1)));   //point to the corresponding ePwm module register address

    //6 cycles to get here
    duty = 100.0 - duty;				//170 cycles
    duty_int = (Uint16)(duty * 0.6);	//151 cycles

//    pEPWMxReg->CMPA.half.CMPA   = duty_int + 1;
    ePWM[module]->CMPA.half.CMPA = duty_int + 1;	//9 cycles


    duty_HR = (Uint16)((duty * 0.6 - duty_int) * 255);	//488 cycles

    duty_HR = 254 - duty_HR;		//0 cycle
    duty_HR = duty_HR << 8U;		//0 cycle

//    pEPWMxReg->CMPA.half.CMPAHR = duty_HR;
    ePWM[module]->CMPA.half.CMPAHR = duty_HR;		//7 cycles


}
#endif

void ePwmSetBuck1Duty_IQ(_iq14 duty)
{
//	EPWM1A_REG_POINTER_CMPA = ((16384 - duty)*100)>>14U;
	EPWM1A_REG_POINTER_CMPA = ((16384 - duty)*EPWM1_PERIOD_COUNT)>>14U;
}

void ePwmSetBuck2Duty_IQ(_iq14 duty)
{
//	EPWM1A_REG_POINTER_CMPA = ((16384 - duty)*100)>>14U;
	EPWM2A_REG_POINTER_CMPA = ((16384 - duty)*EPWM2_PERIOD_COUNT)>>14U;
}

void ePwmSetBuck3Duty_IQ(_iq14 duty)
{
//	EPWM1A_REG_POINTER_CMPA = ((16384 - duty)*100)>>14U;
	EPWM4A_REG_POINTER_CMPA = ((16384 - duty)*EPWM4_PERIOD_COUNT)>>14U;
}

void ePwmSetBuck4Duty_IQ(_iq14 duty)
{
	EPWM1B_REG_POINTER_CMPB = ((16384 - duty)*EPWM1_PERIOD_COUNT)>>14U;
}

void ePwmSetBuck5Duty_IQ(_iq14 duty)
{
	EPWM2B_REG_POINTER_CMPB = ((16384 - duty)*EPWM2_PERIOD_COUNT)>>14U;
}

void ePwmSetBuck6Duty_IQ(_iq14 duty)
{
	EPWM4B_REG_POINTER_CMPB = ((16384 - duty)*EPWM4_PERIOD_COUNT)>>14U;
}

void ePwmSetBoostAHRDuty_IQ(_iq14 duty)
{
	//cpu take 7 cycles to enter the function call
//    struct EPWM_REGS * pEPWMxReg;
//    Uint32 duty_HR;
//    Uint16 duty_int;

//    pEPWMxReg = (struct EPWM_REGS *)(EPWMxREG_BASEADDRESS + (EPWMxREG_MODULE_OFFSET * (module - 1)));   //point to the corresponding ePwm module register address

    //6 cycles to get here
//    duty = _IQ14(1.0) - duty;				//3 cycles
//    duty_HR = duty * 60;				//7 cycles
//    duty_int = (duty_HR)>>14U;		//4 cycles

//    pEPWMxReg->CMPA.half.CMPA   = duty_int + 1;
//    ePWM[module]->CMPA.half.CMPA = duty_int + 1;	//9 cycles
    //ePWM[module]->CMPA.half.CMPA = ((_IQ14(1.0) - duty)*60)>>14U;
//	  ePWM[module]->CMPA.half.CMPA = ((16384 - duty)*60)>>14U;
	EPWM5A_REG_POINTER_CMPA = ((16384 - duty)*EPWM5_PERIOD_COUNT)>>14U;

//    duty_HR = (duty_HR>>6U) - (duty_int <<8U) - 1;	//12 cycles
//
//    duty_HR = 254 - duty_HR;		//0 cycle
//    duty_HR = duty_HR << 8U;		//0 cycle

//    duty_HR = (((_IQ14(1.0) - duty)*60)>>6U);
//    pEPWMxReg->CMPA.half.CMPAHR = duty_HR;
//    ePWM[module]->CMPA.half.CMPAHR = duty_HR;		//7 cycles

//    ePWM[module]->CMPA.half.CMPAHR = (254 - ((((_IQ14(1.0) - duty)*60)>>6U)&0x000000ff - 1))<<8U;
//	  ePWM[module]->CMPA.half.CMPAHR = (254 - ((((16384 - duty)*60)>>6U)&0x000000ff - 1))<<8U;
	EPWM5A_REG_POINTER_CMPAHR =  (254 - ((((16384 - duty)*EPWM5_PERIOD_COUNT)>>6U)&0x000000ff - 1))<<8U;

}

void ePwmSetBoostBHRDuty_IQ(_iq14 duty)
{
	//cpu take 7 cycles to enter the function call

	EPWM3A_REG_POINTER_CMPA = ((16384 - duty)*EPWM3_PERIOD_COUNT)>>14U;

	EPWM3A_REG_POINTER_CMPAHR =  (254 - ((((16384 - duty)*EPWM3_PERIOD_COUNT)>>6U)&0x000000ff - 1))<<8U;

}

//channel mapping in this system:
//	channel:
//		GPIO0 -> PWM1A = buck1
//		GPIO2 -> PWM2A = buck2
//		GPIO6 -> PWM4A = buck3
//		GPIO1 -> PWM1B = buck4
//		GPIO3 -> PWM2B = buck5
//		GPIO7 -> PWM4B = buck6

void ePwmEnableOutput(Uint16 channel)
{
	EALLOW;
	switch(channel)
	{
	case BoostA:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAPUD.bit.GPIO8 = 1;    // Disable pull-up on GPIO8 (EPWM5A)
		    GpioCtrlRegs.GPAPUD.bit.GPIO9 = 1;    // Disable pull-up on GPIO9 (EPWM5B)

		/* Configure EPWM-5 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM5 functional pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAMUX1.bit.GPIO8 = 1;   // Configure GPIO8 as EPWM5A
		    GpioCtrlRegs.GPAMUX1.bit.GPIO9 = 1;   // Configure GPIO9 as EPWM5B
		break;
	case BoostB:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAPUD.bit.GPIO4 = 1;    // Disable pull-up on GPIO4 (EPWM3A)
		    GpioCtrlRegs.GPAPUD.bit.GPIO5 = 1;    // Disable pull-up on GPIO5 (EPWM3B)

		/* Configure EPwm-3 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM3 functional pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAMUX1.bit.GPIO4 = 1;   // Configure GPIO4 as EPWM3A
		    GpioCtrlRegs.GPAMUX1.bit.GPIO5 = 1;   // Configure GPIO5 as EPWM3B
		break;
	case Buck1:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAPUD.bit.GPIO0 = 1;    // Disable pull-up on GPIO0 (EPWM1A)
//		    GpioCtrlRegs.GPAPUD.bit.GPIO1 = 1;    // Disable pull-up on GPIO1 (EPWM1B)

		/* Configure EPWM-1 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM1 functional pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAMUX1.bit.GPIO0 = 1;   // Configure GPIO0 as EPWM1A
//		    GpioCtrlRegs.GPAMUX1.bit.GPIO1 = 1;   // Configure GPIO1 as EPWM1B
		break;
	case Buck2:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAPUD.bit.GPIO2 = 1;    // Disable pull-up on GPIO2 (EPWM2A)
//		    GpioCtrlRegs.GPAPUD.bit.GPIO3 = 1;    // Disable pull-up on GPIO3 (EPWM2B)

		/* Configure EPwm-2 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM2 functional pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAMUX1.bit.GPIO2 = 1;   // Configure GPIO2 as EPWM2A
//		    GpioCtrlRegs.GPAMUX1.bit.GPIO3 = 1;   // Configure GPIO3 as EPWM2B
		break;
	case Buck3:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAPUD.bit.GPIO6 = 1;    // Disable pull-up on GPIO6 (EPWM4A)
//		    GpioCtrlRegs.GPAPUD.bit.GPIO7 = 1;    // Disable pull-up on GPIO7 (EPWM4B)

		/* Configure EPWM-4 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM4 functional pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAMUX1.bit.GPIO6 = 1;   // Configure GPIO6 as EPWM4A
//		    GpioCtrlRegs.GPAMUX1.bit.GPIO7 = 1;   // Configure GPIO7 as EPWM4B
		break;
	case Buck4:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAPUD.bit.GPIO0 = 1;    // Disable pull-up on GPIO0 (EPWM1A)
		    GpioCtrlRegs.GPAPUD.bit.GPIO1 = 1;    // Disable pull-up on GPIO1 (EPWM1B)

		/* Configure EPWM-1 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM1 functional pins.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAMUX1.bit.GPIO0 = 1;   // Configure GPIO0 as EPWM1A
		    GpioCtrlRegs.GPAMUX1.bit.GPIO1 = 1;   // Configure GPIO1 as EPWM1B
		break;
	case Buck5:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAPUD.bit.GPIO2 = 1;    // Disable pull-up on GPIO2 (EPWM2A)
		    GpioCtrlRegs.GPAPUD.bit.GPIO3 = 1;    // Disable pull-up on GPIO3 (EPWM2B)

		/* Configure EPwm-2 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM2 functional pins.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAMUX1.bit.GPIO2 = 1;   // Configure GPIO2 as EPWM2A
		    GpioCtrlRegs.GPAMUX1.bit.GPIO3 = 1;   // Configure GPIO3 as EPWM2B
		break;
	case Buck6:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAPUD.bit.GPIO6 = 1;    // Disable pull-up on GPIO6 (EPWM4A)
		    GpioCtrlRegs.GPAPUD.bit.GPIO7 = 1;    // Disable pull-up on GPIO7 (EPWM4B)

		/* Configure EPWM-4 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM4 functional pins.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAMUX1.bit.GPIO6 = 1;   // Configure GPIO6 as EPWM4A
		    GpioCtrlRegs.GPAMUX1.bit.GPIO7 = 1;   // Configure GPIO7 as EPWM4B
		break;
	default:	//error parameter
		break;
	}

    EDIS;

}

void ePwmDisableOutput(Uint16 channel)
{
	EALLOW;
	switch(channel)
	{
	case BoostA:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAPUD.bit.GPIO8 = 1;    // Disable pull-up on GPIO8 (EPWM5A)
		    GpioCtrlRegs.GPAPUD.bit.GPIO9 = 1;    // Disable pull-up on GPIO9 (EPWM5B)

		/* Configure EPWM-5 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM5 functional pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAMUX1.bit.GPIO8 = 0;   // Configure GPIO8 as IO rather than EPWM5A
		    GpioCtrlRegs.GPAMUX1.bit.GPIO9 = 0;   // Configure GPIO9 as IO rather than EPWM5B
		break;
	case BoostB:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAPUD.bit.GPIO4 = 1;    // Disable pull-up on GPIO4 (EPWM3A)
		    GpioCtrlRegs.GPAPUD.bit.GPIO5 = 1;    // Disable pull-up on GPIO5 (EPWM3B)

		/* Configure EPwm-3 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM3 functional pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAMUX1.bit.GPIO4 = 0;   // Configure GPIO4 as IO rather than EPWM3A
		    GpioCtrlRegs.GPAMUX1.bit.GPIO5 = 0;   // Configure GPIO5 as IO rather than EPWM3B
		break;
	case Buck1:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAPUD.bit.GPIO0 = 1;    // Disable pull-up on GPIO0 (EPWM1A)
//		    GpioCtrlRegs.GPAPUD.bit.GPIO1 = 1;    // Disable pull-up on GPIO1 (EPWM1B)

		/* Configure EPWM-1 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM1 functional pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAMUX1.bit.GPIO0 = 0;   // Configure GPIO0 as IO rather than EPWM1A
//		    GpioCtrlRegs.GPAMUX1.bit.GPIO1 = 1;   // Configure GPIO1 as EPWM1B

		    GpioDataRegs.GPACLEAR.bit.GPIO0 = 1;   // Clear GPIO0 output to low
		break;
	case Buck2:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAPUD.bit.GPIO2 = 1;    // Disable pull-up on GPIO2 (EPWM2A)
//		    GpioCtrlRegs.GPAPUD.bit.GPIO3 = 1;    // Disable pull-up on GPIO3 (EPWM2B)

		/* Configure EPwm-2 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM2 functional pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAMUX1.bit.GPIO2 = 0;   // Configure GPIO2 as IO rather than EPWM2A
//		    GpioCtrlRegs.GPAMUX1.bit.GPIO3 = 1;   // Configure GPIO3 as EPWM2B
		break;
	case Buck3:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAPUD.bit.GPIO6 = 1;    // Disable pull-up on GPIO6 (EPWM4A)
//		    GpioCtrlRegs.GPAPUD.bit.GPIO7 = 1;    // Disable pull-up on GPIO7 (EPWM4B)

		/* Configure EPWM-4 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM4 functional pins.
		// Comment out other unwanted lines.

		    GpioCtrlRegs.GPAMUX1.bit.GPIO6 = 0;   // Configure GPIO6 as IO rather than EPWM4A
//		    GpioCtrlRegs.GPAMUX1.bit.GPIO7 = 1;   // Configure GPIO7 as EPWM4B
		break;
	case Buck4:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAPUD.bit.GPIO0 = 1;    // Disable pull-up on GPIO0 (EPWM1A)
		    GpioCtrlRegs.GPAPUD.bit.GPIO1 = 1;    // Disable pull-up on GPIO1 (EPWM1B)

		/* Configure EPWM-1 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM1 functional pins.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAMUX1.bit.GPIO0 = 1;   // Configure GPIO0 as EPWM1A
		    GpioCtrlRegs.GPAMUX1.bit.GPIO1 = 0;   // Configure GPIO1 as IO rather than EPWM1B
		break;
	case Buck5:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAPUD.bit.GPIO2 = 1;    // Disable pull-up on GPIO2 (EPWM2A)
		    GpioCtrlRegs.GPAPUD.bit.GPIO3 = 1;    // Disable pull-up on GPIO3 (EPWM2B)

		/* Configure EPwm-2 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM2 functional pins.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAMUX1.bit.GPIO2 = 1;   // Configure GPIO2 as EPWM2A
		    GpioCtrlRegs.GPAMUX1.bit.GPIO3 = 0;   // Configure GPIO3 as IO rather than EPWM2B
		break;
	case Buck6:
		/* Disable internal pull-up for the selected output pins
		   for reduced power consumption */
		// Pull-ups can be enabled or disabled by the user.
		// This will enable the pullups for the specified pins.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAPUD.bit.GPIO6 = 1;    // Disable pull-up on GPIO6 (EPWM4A)
		    GpioCtrlRegs.GPAPUD.bit.GPIO7 = 1;    // Disable pull-up on GPIO7 (EPWM4B)

		/* Configure EPWM-4 pins using GPIO regs*/
		// This specifies which of the possible GPIO pins will be EPWM4 functional pins.
		// Comment out other unwanted lines.

//		    GpioCtrlRegs.GPAMUX1.bit.GPIO6 = 1;   // Configure GPIO6 as EPWM4A
		    GpioCtrlRegs.GPAMUX1.bit.GPIO7 = 0;   // Configure GPIO7 as IO rather than EPWM4B
		break;
	default:	//error parameter
		break;
	}

    EDIS;

}

