/* TI File $Revision: /main/1 $												*/
/* Checkin $Date: 15th Mar, 2013 $											*/
/****************************************************************************/
/*																			*/
/* FILE:	main.c															*/
/*																			*/
/* TITLE:	main operation of LED project 									*/
/*																			*/
/* This file contains task scheduling, system initialization calls for 		*/
/* SAE LED project.															*/
/*																			*/
/*																			*/
/****************************************************************************/
/* $Release Date: $															*/
/****************************************************************************/


#include "DSP2803x_Device.h"
#include "DSP2803x_Examples.h"
#include "sys_config.h"
#include "IQMathLib.h"
#include "SQMath.h"
#include "controller.h"
#include "ePWM.h"
#include "ADC.h"
#include "GPIO.h"
#include "eCAN.h"
#include "comm.h"
#include "system.h"

void cpuTimerInit(void);

Uint16 boostVoutAReference;
Uint16 boostVoutBReference;

Uint16 buckILED1Reference;

_iq gGUI_boostA;

#define BUCK_I_LED_1_REFERENCE	1200
//#define BUCK_I_LED_1_REFERENCE	2500

#define BOOST_VOUT_A_OVER_VOLTAGE_THRESHOLD		3103	// Vmax = 25V, (25/10)*4096/3.3
#define BOOST_VOUT_B_OVER_VOLTAGE_THRESHOLD		3103	// Vmax = 25V, (25/10)*4096/3.3
#define BUCK_ILED_1_OVER_CURRENT_THRESHOLD		2978	// Imax = 1.2A, (1.2*0.2*10)*4096/3.3
#define BUCK_ILED_2_OVER_CURRENT_THRESHOLD		2978	// Imax = 1.2A, (1.2*0.2*10)*4096/3.3
#define BUCK_ILED_3_OVER_CURRENT_THRESHOLD		2978	// Imax = 1.2A, (1.2*0.2*10)*4096/3.3
#define BUCK_ILED_4_OVER_CURRENT_THRESHOLD		2978	// Imax = 1.2A, (1.2*0.2*10)*4096/3.3
#define BUCK_ILED_5_OVER_CURRENT_THRESHOLD		2978	// Imax = 1.2A, (1.2*0.2*10)*4096/3.3
#define BUCK_ILED_6_OVER_CURRENT_THRESHOLD		2978	// Imax = 1.2A, (1.2*0.2*10)*4096/3.3

#define BUCK_ILED_UNDER_VOLTAGE_CURRENT			993		// Ilimited = 0.4A, (0.4*0.2*10)*4096/3.3

#define BATTERY_VOLTAGE_MAX_THRESHOLD			2482	//Vbat.max = 20V, (20/10)*4096/3.3
#define BATTERY_VOLTAGE_MIN_THRESHOLD			991		//Vbat.min = 8V, (8/10)*4096/3.3
#define BATTERY_VOLTAGE_ULTRA_LOW_THRESHOLD		806		//Vbat.min = 6.5V, (6/10)*4096/3.3

#define LED_TEMPERATURE_MAX_THRESHOLD			1500	//??? no idea...


controllerDataBuffer_t boostVoutA;
controllerDataBuffer_t boostVoutB;

//controllerDataBuffer_t* pBoostVoutA;

PID_CONTROLLER boostVoutA_PID;
PID_CONTROLLER boostVoutB_PID;
PID_CONTROLLER buckILED1_PID;
PID_CONTROLLER buckILED2_PID;
PID_CONTROLLER buckILED3_PID;
PID_CONTROLLER buckILED4_PID;
PID_CONTROLLER buckILED5_PID;
PID_CONTROLLER buckILED6_PID;

PID_CONTROLLER* pBoostVoutA_PID;
PID_CONTROLLER* pBoostVoutB_PID;
PID_CONTROLLER* pBuckILED1_PID;
PID_CONTROLLER* pBuckILED2_PID;
PID_CONTROLLER* pBuckILED3_PID;
PID_CONTROLLER* pBuckILED4_PID;
PID_CONTROLLER* pBuckILED5_PID;
PID_CONTROLLER* pBuckILED6_PID;

_iq* channel_Ref_Target[9];
_iq buckILED1_Ref_Target;
_iq buckILED2_Ref_Target;
_iq buckILED3_Ref_Target;
_iq buckILED4_Ref_Target;
_iq buckILED5_Ref_Target;
_iq buckILED6_Ref_Target;
_iq boostVoutA_Ref_Target;
_iq boostVoutB_Ref_Target;

int16 SlewError;
int16 slewStep_Boost;
int16 slewStep_Buck;

Uint16 boostVoutA_OverVoltageCount;
Uint16 boostVoutB_OverVoltageCount;
Uint16 buckILED1_OverCurrentCount;
Uint16 buckILED2_OverCurrentCount;
Uint16 buckILED3_OverCurrentCount;
Uint16 buckILED4_OverCurrentCount;
Uint16 buckILED5_OverCurrentCount;
Uint16 buckILED6_OverCurrentCount;

Uint16 batteryOverVoltageCount;
Uint16 batteryUnderVoltageCount;
Uint16 batteryUltraLowVoltageCount;
Uint16 batteryBackToNormalVoltageCount;

Uint16 batterUnderVoltageFlag;
Uint16 batterUltraLowVoltageFlag;

Uint16 LEDOverTemperatureCount;

Uint16 LEDType[7];

Uint16 buck1_feedback_ave;

Uint16 boostA_force_reference;
Uint16 boostB_force_reference;
Uint16 boostVoutA_Ref_Target_Buffer;
Uint16 boostVoutB_Ref_Target_Buffer;

Uint16 batteryVoltage;
Uint16 LEDTemperature;

/* add system status flag structure for state machine of the application -- 2013-05-07 */
typedef struct systemStatus
{
	struct
	{
		Uint16 buck1	:1U;	//specify ON/OFF status
		Uint16 buck2	:1U;
		Uint16 buck3	:1U;
		Uint16 buck4	:1U;
		Uint16 buck5	:1U;
		Uint16 buck6	:1U;
		Uint16 boostA	:1U;
		Uint16 boostB	:1U;
	}drive;						//drive bits shall only be updated by bus command, no other routine shall modify these bits.

	struct
	{
		Uint16 mode		:3U;	//8 operation modes, used for state machine in main loop
		Uint16 reserved	:5U;
	}operationMode;

}systemStatus_t;

systemStatus_t gSystemStatus;
systemStatus_t * pSystemStatus;

volatile LED_CMD_0_t* pCommand_0;
volatile LED_CMD_1_t* pCommand_1;
volatile LED_CMD_2_t* pCommand_2;

int16	VTimer0[4];			// Virtual Timers slaved of CPU Timer 0 (A events)
int16	VTimer1[4]; 		// Virtual Timers slaved of CPU Timer 1 (B events)
int16	VTimer2[4]; 		// Virtual Timers slaved of CPU Timer 2 (C events)

eCAN_Data_t can_tx_data;
eCAN_Data_t can_rx_data;

// State Machine function prototypes
//------------------------------------
// Alpha states
void A0(void);	//state A0
void B0(void);	//state B0
void C0(void);	//state C0

// A branch states
void A1(void);	//state A1
void A2(void);	//state A2
void A3(void);	//state A3
void A4(void);	//state A3

// B branch states
void B1(void);	//state B1
void B2(void);	//state B2
void B3(void);	//state B3
void B4(void);	//state B4

// C branch states
void C1(void);	//state C1
void C2(void);	//state C2
void C3(void);	//state C3

// Variable declarations
void (*Alpha_State_Ptr)(void);	// Base States pointer
void (*A_Task_Ptr)(void);		// State pointer A branch
void (*B_Task_Ptr)(void);		// State pointer B branch
void (*C_Task_Ptr)(void);		// State pointer C branch


void main(void) {


//	Uint16 k;

	pSystemStatus = &gSystemStatus;

#if BOOST_A_HR_DUTY_CHECK
    _iq14 duty = _IQ14(0.01);
#endif /* BOOST_A_HR_DUTY_CHECK */

    systemInit();

    cpuTimerInit();		/* Init CPU timer for time slice of 1ms, 5ms, 10ms */
    StartCpuTimer0();	/* Start time slice */
    StartCpuTimer1();
    StartCpuTimer2();

	// Tasks State-machine init
	Alpha_State_Ptr = &A0;
	A_Task_Ptr = &A1;
	B_Task_Ptr = &B1;
	C_Task_Ptr = &C1;

	VTimer0[0] = 0;
	VTimer1[0] = 0;
	VTimer1[1] = 0;
	VTimer2[0] = 0;

    coefficientInitialization();

    //Initialize target values
    buckILED1_Ref_Target = 0;
    buckILED2_Ref_Target = 0;
    buckILED3_Ref_Target = 0;
    buckILED4_Ref_Target = 0;
    buckILED5_Ref_Target = 0;
    buckILED6_Ref_Target = 0;
    boostVoutA_Ref_Target = 2234;		//18V target as initial condition
    boostVoutB_Ref_Target = 2234;		//18V target as initial condition

    channel_Ref_Target[Buck1] = &buckILED1_Ref_Target;
    channel_Ref_Target[Buck2] = &buckILED2_Ref_Target;
    channel_Ref_Target[Buck3] = &buckILED3_Ref_Target;
    channel_Ref_Target[Buck4] = &buckILED4_Ref_Target;
    channel_Ref_Target[Buck5] = &buckILED5_Ref_Target;
    channel_Ref_Target[Buck6] = &buckILED6_Ref_Target;
    channel_Ref_Target[BoostA] = &boostVoutA_Ref_Target;
    channel_Ref_Target[BoostB] = &boostVoutB_Ref_Target;


    //Initialize slew steps
    slewStep_Boost = 15;
    slewStep_Buck = 15;

    //Initialize LED type
    LEDType[Buck1] = LED_Type_Detecting;
    LEDType[Buck2] = LED_Type_Detecting;
    LEDType[Buck3] = LED_Type_Detecting;
    LEDType[Buck4] = LED_Type_Detecting;
    LEDType[Buck5] = LED_Type_Detecting;
    LEDType[Buck6] = LED_Type_Detecting;


    //Initialize protection count values
    boostVoutA_OverVoltageCount = 0;
    boostVoutB_OverVoltageCount = 0;
    buckILED1_OverCurrentCount = 0;
    buckILED2_OverCurrentCount = 0;
    buckILED3_OverCurrentCount = 0;
    buckILED4_OverCurrentCount = 0;
    buckILED5_OverCurrentCount = 0;
    buckILED6_OverCurrentCount = 0;

    batteryOverVoltageCount = 0;
    batteryUnderVoltageCount = 0;
    batteryBackToNormalVoltageCount = 0;

    LEDOverTemperatureCount = 0;

    batterUnderVoltageFlag = FALSE;

    boostA_force_reference = Off;
    boostB_force_reference = Off;


    batteryVoltage = 0;
    LEDTemperature = 0;

    buckDimmingInit();

//    pBoostVoutA = &boostVoutA;		/* implement point to data structure for better performance */

    EnableInterrupts();				/* Enable global interrupts */

//    EINT;			/* Redundant */

    ePwmStart();

    setDebugLED4();       // LED4 on
    clearDebugLED5();     // LED5 off

    /* initialize system status */
    *(Uint16*)(pSystemStatus) = 0U;

#if BUCK_1_DUTY_CHANGE_CHECK
    Uint16 direction = UP;
#endif /* BUCK_1_DUTY_CHANGE_CHECK */

//=================================================================================
//	BACKGROUND (BG) LOOP
//=================================================================================

//--------------------------------- FRAMEWORK -------------------------------------
    while(1)
	{
		// State machine entry & exit point
		//===========================================================
		(*Alpha_State_Ptr)();	// jump to an Alpha state (A0,B0,...)
		//===========================================================
//		ServiceRoutine(&commros);

    }
}//END MAIN CODE

//=================================================================================
//	STATE-MACHINE SEQUENCING AND SYNCRONIZATION
//=================================================================================

//--------------------------------- FRAMEWORK -------------------------------------

void A0(void)
{
	// loop rate synchronizer for A-tasks
	if(CpuTimer0Regs.TCR.bit.TIF == 1)
	{
		CpuTimer0Regs.TCR.bit.TIF = 1;	// clear flag
		//-----------------------------------------------------------
		(*A_Task_Ptr)();		// jump to an A Task (A1,A2,A3,...)
		//-----------------------------------------------------------
		VTimer0[0]++;			// virtual timer 0, instance 0 (spare
	}
	Alpha_State_Ptr = &B0;		// Comment out to allow only A tasks
}

void B0(void)
{
	// loop rate synchronizer for B-tasks
	if(CpuTimer1Regs.TCR.bit.TIF == 1)
	{
		CpuTimer1Regs.TCR.bit.TIF = 1;				// clear flag
		//-----------------------------------------------------------
		(*B_Task_Ptr)();		// jump to a B Task (B1,B2,B3,...)
		//-----------------------------------------------------------
		VTimer1[0]++;			// virtual timer 1, instance 0 (used to control SPI LEDs
	}
	Alpha_State_Ptr = &C0;
}

void C0(void)
{
	// loop rate synchronizer for C-tasks
	if(CpuTimer2Regs.TCR.bit.TIF == 1)
	{
		CpuTimer2Regs.TCR.bit.TIF = 1;				// clear flag
		//-----------------------------------------------------------
		(*C_Task_Ptr)();		// jump to a C Task (C1,C2,C3,...)
		//-----------------------------------------------------------
		VTimer2[0]++;			// virtual timer 2, instance 0 (spare)
	}
	Alpha_State_Ptr = &A0;		// Back to State A0
}



/*==============================================*/
/*	TASKS										*/
/*  --2ms base--:								*/
/*	A1: slew rate control (soft start)			*/
/*	A2: Boost over voltage protection			*/
/*	A3: dummy									*/
/*	A4: dummy									*/
/*												*/
/*	--20ms base--:								*/
/*	B1: Communication update					*/
/*	B2: Vbat, V3.3, Temp monitoring				*/
/*	B3: System status update					*/
/*	B4: Spare									*/
/*												*/
/*	--100ms base--:								*/
/*  C1: Status LED blink						*/
/*	C2: Spare									*/
/*												*/
/*==============================================*/

//=================================================================================
//	A - TASKS
//=================================================================================

//--------------------------------------------------------
void A1(void) // Slewrates (soft-start) of references
//--------------------------------------------------------
// Task runs every 2ms (CpuTimer0 period [1ms] * 2 "A" tasks active)
// Slows the changing of a controller's reference by Slewsteps
{
	//  Umax Clamping
	pBoostVoutA_PID->param.Umax = _IQ(0.68);
	pBoostVoutB_PID->param.Umax = _IQ(0.68);
	pBuckILED1_PID->param.Umax = _IQ(0.90);
	pBuckILED2_PID->param.Umax = _IQ(0.90);
	pBuckILED3_PID->param.Umax = _IQ(0.90);
	pBuckILED4_PID->param.Umax = _IQ(0.90);
	pBuckILED5_PID->param.Umax = _IQ(0.90);
	pBuckILED6_PID->param.Umax = _IQ(0.90);

	//---------------------------------------------------------
	// Check Under Voltage Condition
	if(TRUE == batterUnderVoltageFlag)
	{
//		//Set output power to a limited low level;
//		if(buckILED1_Ref_Target > BUCK_ILED_UNDER_VOLTAGE_CURRENT)
//		{
//			buckILED1_Ref_Target = BUCK_ILED_UNDER_VOLTAGE_CURRENT;
//		}
//		if(buckILED2_Ref_Target > BUCK_ILED_UNDER_VOLTAGE_CURRENT)
//		{
//			buckILED2_Ref_Target = BUCK_ILED_UNDER_VOLTAGE_CURRENT;
//		}
//		if(buckILED3_Ref_Target > BUCK_ILED_UNDER_VOLTAGE_CURRENT)
//		{
//			buckILED3_Ref_Target = BUCK_ILED_UNDER_VOLTAGE_CURRENT;
//		}
//		if(buckILED4_Ref_Target > BUCK_ILED_UNDER_VOLTAGE_CURRENT)
//		{
//			buckILED4_Ref_Target = BUCK_ILED_UNDER_VOLTAGE_CURRENT;
//		}
//		if(buckILED5_Ref_Target > BUCK_ILED_UNDER_VOLTAGE_CURRENT)
//		{
//			buckILED5_Ref_Target = BUCK_ILED_UNDER_VOLTAGE_CURRENT;
//		}
//		if(buckILED6_Ref_Target > BUCK_ILED_UNDER_VOLTAGE_CURRENT)
//		{
//			buckILED6_Ref_Target = BUCK_ILED_UNDER_VOLTAGE_CURRENT;
//		}
	}
	else if(TRUE == batterUltraLowVoltageFlag)
	{
		//Set output to off
//		buckILED1_Ref_Target = 0;
//		buckILED2_Ref_Target = 0;
//		buckILED3_Ref_Target = 0;
//		buckILED4_Ref_Target = 0;
//		buckILED5_Ref_Target = 0;
//		buckILED6_Ref_Target = 0;

	}
	else
	{
		//nothing...
	}

	//---------------------------------------------------------
	// Boost A
	SlewError = (pBoostVoutA_PID->term.Ref - boostVoutA_Ref_Target);
	if (SlewError > slewStep_Boost)		pBoostVoutA_PID->term.Ref = pBoostVoutA_PID->term.Ref - slewStep_Boost;
	else
	if (SlewError < (-slewStep_Boost) )	pBoostVoutA_PID->term.Ref = pBoostVoutA_PID->term.Ref + slewStep_Boost;
	else								pBoostVoutA_PID->term.Ref = boostVoutA_Ref_Target;
	//---------------------------------------------------------

	//---------------------------------------------------------
	// Boost B
	SlewError = (pBoostVoutB_PID->term.Ref - boostVoutB_Ref_Target);
	if (SlewError > slewStep_Boost)		pBoostVoutB_PID->term.Ref = pBoostVoutB_PID->term.Ref - slewStep_Boost;
	else
	if (SlewError < (-slewStep_Boost) )	pBoostVoutB_PID->term.Ref = pBoostVoutB_PID->term.Ref + slewStep_Boost;
	else								pBoostVoutB_PID->term.Ref = boostVoutB_Ref_Target;
	//---------------------------------------------------------

	// Buck 1
	//---------------------------------------------------------
	SlewError = (pBuckILED1_PID->term.Ref - buckILED1_Ref_Target);
	if (SlewError > slewStep_Buck)			pBuckILED1_PID->term.Ref = pBuckILED1_PID->term.Ref - slewStep_Buck;
	else if (SlewError < (-slewStep_Buck) )	pBuckILED1_PID->term.Ref = pBuckILED1_PID->term.Ref + slewStep_Buck;
	else									pBuckILED1_PID->term.Ref = buckILED1_Ref_Target;

	// Buck 2
	//---------------------------------------------------------
	SlewError = (pBuckILED2_PID->term.Ref - buckILED2_Ref_Target);
	if (SlewError > slewStep_Buck)			pBuckILED2_PID->term.Ref = pBuckILED2_PID->term.Ref - slewStep_Buck;
	else if (SlewError < (-slewStep_Buck) )	pBuckILED2_PID->term.Ref = pBuckILED2_PID->term.Ref + slewStep_Buck;
	else									pBuckILED2_PID->term.Ref = buckILED2_Ref_Target;

	// Buck 3
	//---------------------------------------------------------
	SlewError = (pBuckILED3_PID->term.Ref - buckILED3_Ref_Target);
	if (SlewError > slewStep_Buck)			pBuckILED3_PID->term.Ref = pBuckILED3_PID->term.Ref - slewStep_Buck;
	else if (SlewError < (-slewStep_Buck) )	pBuckILED3_PID->term.Ref = pBuckILED3_PID->term.Ref + slewStep_Buck;
	else									pBuckILED3_PID->term.Ref = buckILED3_Ref_Target;

	// Buck 4
	//---------------------------------------------------------
	SlewError = (pBuckILED4_PID->term.Ref - buckILED4_Ref_Target);
	if (SlewError > slewStep_Buck)			pBuckILED4_PID->term.Ref = pBuckILED4_PID->term.Ref - slewStep_Buck;
	else if (SlewError < (-slewStep_Buck) )	pBuckILED4_PID->term.Ref = pBuckILED4_PID->term.Ref + slewStep_Buck;
	else									pBuckILED4_PID->term.Ref = buckILED4_Ref_Target;

	// Buck 5
	//---------------------------------------------------------
	SlewError = (pBuckILED5_PID->term.Ref - buckILED5_Ref_Target);
	if (SlewError > slewStep_Buck)			pBuckILED5_PID->term.Ref = pBuckILED5_PID->term.Ref - slewStep_Buck;
	else if (SlewError < (-slewStep_Buck) )	pBuckILED5_PID->term.Ref = pBuckILED5_PID->term.Ref + slewStep_Buck;
	else									pBuckILED5_PID->term.Ref = buckILED5_Ref_Target;

	// Buck 6
	//---------------------------------------------------------
	SlewError = (pBuckILED6_PID->term.Ref - buckILED6_Ref_Target);
	if (SlewError > slewStep_Buck)			pBuckILED6_PID->term.Ref = pBuckILED6_PID->term.Ref - slewStep_Buck;
	else if (SlewError < (-slewStep_Buck) )	pBuckILED6_PID->term.Ref = pBuckILED6_PID->term.Ref + slewStep_Buck;
	else									pBuckILED6_PID->term.Ref = buckILED6_Ref_Target;

//	pBoostVoutA_PID->term.Ref = boostVoutA_Ref_Target;
//	pBoostVoutB_PID->term.Ref = boostVoutB_Ref_Target;
//	pBuckILED1_PID->term.Ref = buckILED1_Ref_Target;
//	pBuckILED2_PID->term.Ref = buckILED2_Ref_Target;
//	pBuckILED3_PID->term.Ref = buckILED3_Ref_Target;
//	pBuckILED4_PID->term.Ref = buckILED4_Ref_Target;
//	pBuckILED5_PID->term.Ref = buckILED5_Ref_Target;
//	pBuckILED6_PID->term.Ref = buckILED6_Ref_Target;

	buckDimmingHandler();

	//-------------------
	A_Task_Ptr = &A2;
	//-------------------
}

//-----------------------------------------------------------------
void A2(void) // Boost over voltage protection
//-----------------------------------------------------------------
// Task runs every 2ms (CpuTimer0 period [1ms] * 2 "A" tasks active)
// Monitors the boost voltage line to protect the circuit
{
	//Boost A
	if(pBoostVoutA_PID->term.Fbk > BOOST_VOUT_A_OVER_VOLTAGE_THRESHOLD)
	{
		boostVoutA_OverVoltageCount++;
		if(boostVoutA_OverVoltageCount >= 3)
		{
			//over voltage for 6ms!
			//enter protection routine
		}
	}
	else
	{
		boostVoutA_OverVoltageCount = 0;
	}

	//Boost B
	if(pBoostVoutB_PID->term.Fbk > BOOST_VOUT_B_OVER_VOLTAGE_THRESHOLD)
	{
		boostVoutB_OverVoltageCount++;
		if(boostVoutB_OverVoltageCount > 2)
		{
			//over voltage for 6ms!
			//enter protection routine
		}
	}
	else
	{
		boostVoutB_OverVoltageCount = 0;
	}

	buckDimmingHandler();

	//-------------------
	A_Task_Ptr = &A3;
	//-------------------
}

//-----------------------------------------------------------------
void A3(void) // Dummy
//-----------------------------------------------------------------
{
	buckDimmingHandler();
	//-------------------
	A_Task_Ptr = &A4;
	//-------------------
}

//-----------------------------------------------------------------
void A4(void) // Dummy
//-----------------------------------------------------------------
{
	buckDimmingHandler();
	//-------------------
	A_Task_Ptr = &A1;
	//-------------------
}

//=================================================================================
//	B - TASKS
//=================================================================================

//----------------------------------------------------
void B1(void) // Communication updates
//----------------------------------------------------
// Task runs every 20ms (CpuTimer1 period [5ms] * 2 "B" tasks active)
// CAN communication messages are to be checked in this task both for TX and RX
{
	//CAN message reception
	if(eCANGetData(MailBox8, &can_rx_data))
	{
		pCommand_0 = (LED_CMD_0_t*)(&can_rx_data.byte[0]);

		pSystemStatus->drive.buck1 = pCommand_0->byte1.all.bit.Buck1;
		pSystemStatus->drive.buck2 = pCommand_0->byte1.all.bit.Buck2;
		pSystemStatus->drive.buck3 = pCommand_0->byte1.all.bit.Buck3;
		pSystemStatus->drive.buck4 = pCommand_0->byte1.all.bit.Buck4;
		pSystemStatus->drive.buck5 = pCommand_0->byte1.all.bit.Buck5;
		pSystemStatus->drive.buck6 = pCommand_0->byte1.all.bit.Buck6;

		boostA_force_reference = pCommand_0->byte1.all.bit.BoostA;
		boostB_force_reference = pCommand_0->byte1.all.bit.BoostB;

		buckILED1_Ref_Target = pCommand_0->byte6.Buck1_ref_low + (pCommand_0->byte7.Buck1_ref_high << 8U);
		boostVoutA_Ref_Target_Buffer = pCommand_0->byte2.BoostA_ref_low + (pCommand_0->byte3.BoostA_ref_high << 8U);
		boostVoutB_Ref_Target_Buffer = pCommand_0->byte4.BoostB_ref_low + (pCommand_0->byte5.BoostB_ref_high << 8U);

		if(pCommand_0->byte1.all.byte & 0x001C)
		{
			pSystemStatus->drive.boostA = On;
		}
		else
		{
			pSystemStatus->drive.boostA = Off;
		}

		if((pCommand_0->byte1.all.byte) & 0x00E0)
		{
			pSystemStatus->drive.boostB = On;
		}
		else
		{
			pSystemStatus->drive.boostB = Off;
		}
	}
	else
	{
		//command 0 is not received...
	}

	if(eCANGetData(MailBox9, &can_rx_data))
	{
		pCommand_1 = (LED_CMD_1_t*)(&can_rx_data.byte[0]);

		buckILED2_Ref_Target = pCommand_1->byte0.Buck2_ref_low + (pCommand_1->byte1.Buck2_ref_high << 8U);
		buckILED3_Ref_Target = pCommand_1->byte2.Buck3_ref_low + (pCommand_1->byte3.Buck3_ref_high << 8U);
		buckILED4_Ref_Target = pCommand_1->byte4.Buck4_ref_low + (pCommand_1->byte5.Buck4_ref_high << 8U);
		buckILED5_Ref_Target = pCommand_1->byte6.Buck5_ref_low + (pCommand_1->byte7.Buck5_ref_high << 8U);
	}
	else
	{
		//command 1 is not received...
	}

	if(eCANGetData(MailBox10, &can_rx_data))
	{
		pCommand_2 = (LED_CMD_2_t*)(&can_rx_data.byte[0]);

		buckILED6_Ref_Target = pCommand_2->byte0.Buck6_ref_low + (pCommand_2->byte1.Buck6_ref_high << 8U);

	}
	else
	{
		//command 2 is not received...
	}

	buck1_feedback_ave = (buck1_feedback_ave + buckILED1_PID.term.Fbk)/2;

	//CAN message transmission
	can_tx_data.identifier.standard = 0x401;
	can_tx_data.length = 8U;
//	can_tx_data.byte[0] = (Uint16) (buckILED1_PID.term.Fbk);
//	can_tx_data.byte[1] = (Uint16) (buckILED1_PID.term.Fbk >> 8U);
	can_tx_data.byte[0] = (Uint16) (buck1_feedback_ave);
	can_tx_data.byte[1] = (Uint16) (buck1_feedback_ave >> 8U);
	can_tx_data.byte[2] = (Uint16) (buckILED2_PID.term.Fbk);
	can_tx_data.byte[3] = (Uint16) (buckILED2_PID.term.Fbk >> 8U);
	can_tx_data.byte[4] = (Uint16) (buckILED3_PID.term.Fbk);
	can_tx_data.byte[5] = (Uint16) (buckILED3_PID.term.Fbk >> 8U);
	can_tx_data.byte[6] = (Uint16) (buckILED4_PID.term.Fbk);
	can_tx_data.byte[7] = (Uint16) (buckILED4_PID.term.Fbk >> 8U);

	eCANTransmitData(MailBox0, &can_tx_data);

	can_tx_data.identifier.standard = 0x402;
	can_tx_data.length = 8U;
	can_tx_data.byte[0] = (Uint16) (buckILED5_PID.term.Fbk);
	can_tx_data.byte[1] = (Uint16) (buckILED5_PID.term.Fbk >> 8U);
	can_tx_data.byte[2] = (Uint16) (buckILED6_PID.term.Fbk);
	can_tx_data.byte[3] = (Uint16) (buckILED6_PID.term.Fbk >> 8U);
	can_tx_data.byte[4] = (Uint16) (boostVoutA_PID.term.Fbk);
	can_tx_data.byte[5] = (Uint16) (boostVoutA_PID.term.Fbk >> 8U);
	can_tx_data.byte[6] = (Uint16) (boostVoutB_PID.term.Fbk);
	can_tx_data.byte[7] = (Uint16) (boostVoutB_PID.term.Fbk >> 8U);

	eCANTransmitData(MailBox1, &can_tx_data);

	can_tx_data.identifier.standard = 0x403;
	can_tx_data.length = 8U;
	can_tx_data.byte[0] = (Uint16) (batteryVoltage);
	can_tx_data.byte[1] = (Uint16) (batteryVoltage >> 8U);
	can_tx_data.byte[2] = (Uint16) (LEDTemperature);
	can_tx_data.byte[3] = (Uint16) (LEDTemperature >> 8U);
	can_tx_data.byte[4] = (Uint16) 0;
	can_tx_data.byte[5] = (Uint16) 0;
	can_tx_data.byte[6] = (Uint16) 0;
	can_tx_data.byte[7] = (Uint16) 0;

	eCANTransmitData(MailBox2, &can_tx_data);

	struct ECAN_REGS ECanaShadow;
	ECanaShadow.CANES.bit.SMA = ECanaRegs.CANES.bit.SMA;
	if(ECanaShadow.CANES.bit.SMA)	//eCAN suspended.
	{
		ECanaShadow.CANES.all = 0x00000020;
		EALLOW;
		ECanaRegs.CANES.all = ECanaShadow.CANES.all;	//clears the suspend bit.
		EDIS;
	}

	//-----------------
	B_Task_Ptr = &B2;
	//-----------------
}

#define BATTERY_VOLTAGE_ADC_ELEMENT	0
#define LED_SET_SIGNAL_ADC_ELEMENT	1
#define TEMPERATURE_SIGNAL_ADC_ELEMENT	2

//----------------------------------------------------
void B2(void) // Monitor Vbat and Temperature value and perform protection routines
//----------------------------------------------------
// Vbat, V3.3, Temperature monitoring
{
	Uint16 adcResult[3];
	if(adcGetConversionResult(adcResult))
	{
	    batteryVoltage = adcResult[BATTERY_VOLTAGE_ADC_ELEMENT];
	    LEDTemperature = adcResult[TEMPERATURE_SIGNAL_ADC_ELEMENT];

		if(adcResult[BATTERY_VOLTAGE_ADC_ELEMENT] > BATTERY_VOLTAGE_MAX_THRESHOLD)
		{
			//battery over voltage
		    batteryOverVoltageCount++;
		    if(batteryOverVoltageCount >= 3)
		    {
		    	//battery over voltage for over 60ms
		    	//enter protection routine
		    }
		    batteryUnderVoltageCount = 0;	//clears under voltage count
		}
		else if((adcResult[BATTERY_VOLTAGE_ADC_ELEMENT] < BATTERY_VOLTAGE_MIN_THRESHOLD)&&(adcResult[BATTERY_VOLTAGE_ADC_ELEMENT] > BATTERY_VOLTAGE_ULTRA_LOW_THRESHOLD))
		{
			//battery under voltage (6.5V < Vbat < 8V)
			batteryUnderVoltageCount++;
			if(batteryUnderVoltageCount >= 300)
			{
		    	//battery over voltage for over 60ms
		    	//enter protection routine

				//set under voltage flag
				batterUnderVoltageFlag = TRUE;

				batterUltraLowVoltageFlag = FALSE;
				batteryUltraLowVoltageCount = 0;
			}
			batteryOverVoltageCount = 0;	//clears over voltage count
		}
		else if(adcResult[BATTERY_VOLTAGE_ADC_ELEMENT] < BATTERY_VOLTAGE_ULTRA_LOW_THRESHOLD)
		{
			//battery voltage ultra low
			batteryUltraLowVoltageCount++;
			if(batteryUltraLowVoltageCount >= 200)
			{
				//battery ultra low voltage for over 60ms
				//enter protection routine

				//set ultra low voltage flag
				batterUltraLowVoltageFlag = TRUE;
				batterUnderVoltageFlag = FALSE;

				batteryUnderVoltageCount = 0;
			}
		}
		else
		{
			 batteryOverVoltageCount = 0;	//clears over voltage count

			 if(batteryUnderVoltageCount != 0)
			 {
				 batteryBackToNormalVoltageCount++;
				 if(batteryBackToNormalVoltageCount > 200)	//after 4s, to avoid blinking
				 {
					 batteryUnderVoltageCount = 0;	//clears under voltage count

					 batteryBackToNormalVoltageCount = 0;
					 batterUnderVoltageFlag = FALSE;	//clears under voltage count
				 }
			 }
			 else if(batteryUltraLowVoltageCount != 0)
			 {
				 batteryBackToNormalVoltageCount++;
				 if(batteryBackToNormalVoltageCount > 200)	//after 4s, to avoid blinking
				 {
					 batteryUltraLowVoltageCount = 0;	//clears ultra low voltage count

					 batteryBackToNormalVoltageCount = 0;
					 batterUltraLowVoltageFlag = FALSE;	//clears ultra low voltage count
				 }
			 }
		}

		if(adcResult[TEMPERATURE_SIGNAL_ADC_ELEMENT] > LED_TEMPERATURE_MAX_THRESHOLD)
		{
			//LED over temperature
			LEDOverTemperatureCount++;
			if(LEDOverTemperatureCount > 4)
			{
				//LED over temperature for 100ms
				//enter protection routine
			}
		}
		else
		{
			LEDOverTemperatureCount = 0;
		}


	}

	//Trigger next ADC conversion for SOC9, 10, 11

	adcSoftwareSOCTrigger(ADC_SOC9);		//Vbat
	adcSoftwareSOCTrigger(ADC_SOC10);		//LED_SET
	adcSoftwareSOCTrigger(ADC_SOC11);		//Temperature



	//-----------------
	B_Task_Ptr = &B3;
	//-----------------
}

//----------------------------------------------------
void B3(void) // ...
//----------------------------------------------------
//System status update.
//Controls and outputs are enabled/disabled here
//Updated every 20ms
{
	//Enable/Disable Buck outputs
	Uint16 i;

	for(i = 0; i < 6; i++)
	{
		if((*(Uint16*)(pSystemStatus)) & (0x01U << (i)))
		{
			if((*channel_Ref_Target[i+1]) > 0)
			{
				ePwmEnableOutput(i+1);
			}
			else
			{
				ePwmDisableOutput(i+1);
			}
		}
		else
		{
			ePwmDisableOutput(i+1);
		}
	}

	//Enable/Disable Boost outputs
	if(pSystemStatus->drive.boostA == On)
	{
		ePwmEnableOutput(BoostA);
	}
	else
	{
		ePwmDisableOutput(BoostA);
	}

	if(pSystemStatus->drive.boostB == On)
	{
		ePwmEnableOutput(BoostB);
	}
	else
	{
		ePwmDisableOutput(BoostB);
	}

	//-----------------
	B_Task_Ptr = &B4;
	//-----------------
}

//----------------------------------------------------
void B4(void) // Force Boost voltage
//----------------------------------------------------
/* Runs every 20ms, checks whether there is Force instructions to change the boost */
/* voltage. And modifies the boost reference accordingly */
{
	if(boostA_force_reference == On)
	{
		if((boostVoutA_Ref_Target_Buffer <= BOOST_A_MAX_VOLTAGE_REFERENCE) && (boostVoutA_Ref_Target_Buffer >= BOOST_A_MIN_VOLTAGE_REFERENCE))
		{
			//update reference only when it is in the range.
			//boostVoutA_PID.term.Ref = boostVoutA_Ref_Target_Buffer;
			boostVoutA_Ref_Target = boostVoutA_Ref_Target_Buffer;
		}
		else	//target out of range, set to safe value
		{
			//boostVoutA_PID.term.Ref = 2234;
			boostVoutA_Ref_Target = 2234;
		}
	}
	else
	{
		//no force condition, use default value
	    boostVoutA_Ref_Target = 2234;		//18V target as initial condition
	}

	if(boostB_force_reference == On)
	{
		if((boostVoutB_Ref_Target_Buffer <= BOOST_B_MAX_VOLTAGE_REFERENCE) && (boostVoutB_Ref_Target_Buffer >= BOOST_B_MIN_VOLTAGE_REFERENCE))
		{
			//update reference only when it is in the range.
			//boostVoutB_PID.term.Ref = boostVoutB_Ref_Target_Buffer;
			boostVoutB_Ref_Target = boostVoutB_Ref_Target_Buffer;
		}
		else	//target out of range, set to safe value
		{
			//boostVoutB_PID.term.Ref = 2234;
			boostVoutB_Ref_Target = 2234;
		}
	}
	else
	{
		//no force condition, use default value
		 boostVoutB_Ref_Target = 2234;		//18V target as initial condition
	}

	//-----------------
	B_Task_Ptr = &B1;
	//-----------------
}

//=================================================================================
//	C - TASKS
//=================================================================================

//----------------------------- USER ----------------------------------------------

//--------------------------------------------------------------
void C1(void)
//--------------------------------------------------------------
// Task runs every 100ms (CpuTimer2 period [50ms] * 2 "C" tasks active)
// Allows user to dynamically change P, I, and D gains while the system is running.
{
// Coefficient Update for 1st (Ch1) Loop

	//-----------------
	C_Task_Ptr = &C2;
	//-----------------
}

//----------------------------------------
void C2(void) // Merging of LED controls & LED "life"-pulse
//----------------------------------------
// Task runs every 100ms (CpuTimer2 period [50ms] * 2 "C" tasks active)
// Blinks an LED and allows all LED controls to be controlled individually or
//   as a group
{
	// toggle an LED on the controlCARD
	static Uint16 blink_count = 0;

	blink_count++;
	if(blink_count > 2)
	{
		//300ms interval
		blink_count = 0;

//		toggleDebugLED4();

	}

	//-----------------
	C_Task_Ptr = &C1;
	//-----------------
}

#if 0
	while(1)
	{
	    if(1 == CpuTimer0Regs.TCR.bit.TIF)  //1ms interval is reached
	    {
	        CpuTimer0Regs.TCR.bit.TIF = 1;  //clear 1ms interrupt flag
	        intervalCount1ms++;

	        gGUI_boostA = boostVoutA_PID.term.Fbk;

	        for(i = 0; i < 6; i++)
	        {
	        	if((*(Uint16*)(pSystemStatus)) & (0x01U << (i)))
	        	{
	        		ePwmEnableOutput(i+1);
	        	}
	        	else
	        	{
	        		ePwmDisableOutput(i+1);
	        	}
	        }

	        if(pSystemStatus->drive.boostA == On)
	        {
	        	ePwmEnableOutput(BoostA);
	        }
	        else
	        {
	        	ePwmDisableOutput(BoostA);
	        }

	        if(pSystemStatus->drive.boostB == On)
			{
				ePwmEnableOutput(BoostB);
			}
			else
			{
				ePwmDisableOutput(BoostB);
			}

	        if(intervalCount1ms % 30 == 0)
	        {
		        if(eCANGetData(8U, &can_rx_data))
		        {
		        	pCommand_0 = (LED_CMD_0_t*)(&can_rx_data.byte[0]);

		        	pSystemStatus->drive.buck1 = pCommand_0->byte1.all.bit.Buck1;
		        	pSystemStatus->drive.buck2 = pCommand_0->byte1.all.bit.Buck2;
		        	pSystemStatus->drive.buck3 = pCommand_0->byte1.all.bit.Buck3;
		        	pSystemStatus->drive.buck4 = pCommand_0->byte1.all.bit.Buck4;
		        	pSystemStatus->drive.buck5 = pCommand_0->byte1.all.bit.Buck5;
		        	pSystemStatus->drive.buck6 = pCommand_0->byte1.all.bit.Buck6;

		        	buckILED1_PID.term.Ref = pCommand_0->byte6.Buck1_ref_low + (pCommand_0->byte7.Buck1_ref_high << 8U);
		        	buckILED1_Ref_Target = pCommand_0->byte6.Buck1_ref_low + (pCommand_0->byte7.Buck1_ref_high << 8U);

		        	if(pCommand_0->byte1.all.byte & 0x001C)
					{
						pSystemStatus->drive.boostA = On;
					}
					else
					{
						pSystemStatus->drive.boostA = Off;
					}

					if((pCommand_0->byte1.all.byte) & 0x00E0)
					{
						pSystemStatus->drive.boostB = On;
					}
					else
					{
						pSystemStatus->drive.boostB = Off;
					}
		        }
		        eCANGetData(9U, &can_rx_data);
		        eCANGetData(10U, &can_rx_data);



	        }

	        if(300 <= intervalCount1ms)
	        {
	            intervalCount1ms = 0;

	            toggleDebugLED4();     //Toggle LED4
	        //    toggleDebugLED5();     //Toggle LED5

	           // eCANTransmitData(2U, &can_tx_data);

//	            if(On == gSystemStatus.drive.boostA)
//	            {
//	            	ePwmDisableOutput(BoostA);
//	            	gSystemStatus.drive.boostA = Off;
//	            }
//	            else
//	            {
//	            	ePwmEnableOutput(BoostA);
//	            	gSystemStatus.drive.boostA = On;
//	            }

#if LED_BLINK_TEST
	            if(buckILED1_PID.term.Ref == 0)
	            {
	            	buckILED1_PID.term.Ref = buckILED1Reference;
	            }
	            else
	            {
	            	buckILED1_PID.term.Ref = 0;
	            }
#endif /* LED_BLINK_TEST */

	        }
	        else
	        {

	        }

#if BOOST_A_HR_DUTY_CHECK
	        /* To check HR duty ratio change */
	        /* Comment these out for close loop boost */
	        duty = duty + _IQ14(0.0001);
		    if(_IQ14(0.5) <= duty)
		    {
			    duty = _IQ14(0.001);
		    }
		    ePwmSetBoostAHRDuty_IQ(duty);
#endif /* BOOST_A_HR_DUTY_CHECK */

#if BUCK_1_DUTY_CHANGE_CHECK

		    /* To check the influence on the boost A output when Buck 1 output current changes */
		    if(UP == direction)
		    {
		    	buckILED1_PID.term.Ref += 1;
		    	buckILED2_PID.term.Ref += 1;
		    	buckILED3_PID.term.Ref += 1;
		    	if(buckILED1_PID.term.Ref > 1200)
				{
	//		    	buckILED1_PID.term.Ref = 200;
		    		direction = DOWN;
				}
		    }
		    else	/* direction == DOWN */
		    {
		    	buckILED1_PID.term.Ref -= 1;
		    	buckILED2_PID.term.Ref -= 1;
		    	buckILED3_PID.term.Ref -= 1;
		    	if(buckILED1_PID.term.Ref < 100)
				{
		    		direction = UP;
				}
		    }
		    /* Above current change dues 480mV ripple in output voltage of Boost A */
		    /* This took 10ms for boost A to be stabilized again */


#endif /* BUCK_1_DUTY_CHANGE_CHECK */



	    }
	    else
	    {
	        //dummy
	    }
	};
}

#endif //#if 0
